{-# LANGUAGE MagicHash #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Curry_SCC ( C_Node (..), d_C_scc, nd_C_scc ) where

import Basics
import qualified Curry_Prelude
import qualified Curry_RedBlackTree
import qualified Curry_SetRBT


data C_Node t0 t1
  = C_Node Curry_Prelude.C_Int (Curry_Prelude.OP_List t1) (Curry_Prelude.OP_List
    t1) t0
  | Choice_C_Node Cover ID (C_Node t0 t1) (C_Node t0 t1)
  | Choices_C_Node Cover ID [C_Node t0 t1]
  | Fail_C_Node Cover FailInfo
  | Guard_C_Node Cover Constraints (C_Node t0 t1)

instance (Show t0, Show t1) => Show (C_Node t0 t1) where
  showsPrec d (Choice_C_Node cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_Node cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_Node cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_Node cd info) = showChar '!'
  showsPrec _ (C_Node x1 x2 x3 x4) = showString "(Node" . (showChar ' ' . (shows
    x1 . (showChar ' ' . (shows x2 . (showChar ' ' . (shows x3 . (showChar ' ' .
    (shows x4 . showChar ')'))))))))

instance (Read t0, Read t1) => Read (C_Node t0 t1) where
  readsPrec d s = readParen ((>) d 10) (\r -> [(C_Node x1 x2 x3 x4, r4) | (_
    , r0) <- readQualified "SCC" "Node" r, (x1, r1) <- readsPrec 11 r0, (x2, r2)
    <- readsPrec 11 r1, (x3, r3) <- readsPrec 11 r2, (x4, r4) <- readsPrec 11
    r3]) s

instance NonDet (C_Node t0 t1) where
  choiceCons = Choice_C_Node
  choicesCons = Choices_C_Node
  failCons = Fail_C_Node
  guardCons = Guard_C_Node
  try (Choice_C_Node cd i x y) = tryChoice cd i x y
  try (Choices_C_Node cd i xs) = tryChoices cd i xs
  try (Fail_C_Node cd info) = Fail cd info
  try (Guard_C_Node cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_Node cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_Node cd i@(NarrowedID _ _) xs) = f cd i xs
  match _ _ f _ _ _ (Choices_C_Node cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_Node cd i _) = error
    ("SCC.Node.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_Node cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_Node cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance (Generable t0, Generable t1) => Generable (C_Node t0 t1) where
  generate s c = Choices_C_Node c (freeID [4] s) [C_Node (generate (leftSupply
    (leftSupply s)) c) (generate (rightSupply (leftSupply s)) c) (generate
    (leftSupply (rightSupply s)) c) (generate (rightSupply (rightSupply s)) c)]

instance (NormalForm t0, NormalForm t1) => NormalForm (C_Node t0 t1) where
  ($!!) cont (C_Node x1 x2 x3 x4) d cs = ($!!) (\y1 d cs -> ($!!) (\y2 d cs ->
    ($!!) (\y3 d cs -> ($!!) (\y4 d cs -> cont (C_Node y1 y2 y3 y4) d cs) x4 d
    cs) x3 d cs) x2 d cs) x1 d cs
  ($!!) cont (Choice_C_Node cd i x y) d cs = nfChoice cont cd i x y cd cs
  ($!!) cont (Choices_C_Node cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_Node cd c e) d cs = guardCons cd c (($!!) cont e d (addCs
    c cs))
  ($!!) _ (Fail_C_Node cd info) _ _ = failCons cd info
  ($##) cont (C_Node x1 x2 x3 x4) d cs = ($##) (\y1 d cs -> ($##) (\y2 d cs ->
    ($##) (\y3 d cs -> ($##) (\y4 d cs -> cont (C_Node y1 y2 y3 y4) d cs) x4 d
    cs) x3 d cs) x2 d cs) x1 d cs
  ($##) cont (Choice_C_Node cd i x y) d cs = gnfChoice cont cd i x y cd cs
  ($##) cont (Choices_C_Node cd i xs) d cs = gnfChoices cont cd i xs d cs
  ($##) cont (Guard_C_Node cd c e) d cs = guardCons cd c (($##) cont e d (addCs
    c cs))
  ($##) _ (Fail_C_Node cd info) _ _ = failCons cd info
  showCons (C_Node _ _ _ _) = "SCC.Node _ _ _ _"
  showCons x = error ("SCC.Node.showCons: no constructor: " ++ show x)
  searchNF search cont (C_Node x1 x2 x3 x4) = search (\y1 -> search (\y2 ->
    search (\y3 -> search (\y4 -> cont (C_Node y1 y2 y3 y4)) x4) x3) x2) x1
  searchNF _ _ x = error ("SCC.Node.searchNF: no constructor: " ++ show x)

instance (Unifiable t0, Unifiable t1) => Unifiable (C_Node t0 t1) where
  (=.=) (C_Node x1 x2 x3 x4) (C_Node y1 y2 y3 y4) d cs = (&) ((=:=) x1 y1 d cs)
    ((&) ((=:=) x2 y2 d cs) ((&) ((=:=) x3 y3 d cs) ((=:=) x4 y4 d cs) d cs) d
    cs) d cs
  (=.=) a b cd _ = Fail_C_Success cd (unificationFail (showCons a) (showCons b))
  (=.<=) (C_Node x1 x2 x3 x4) (C_Node y1 y2 y3 y4) d cs = (&) ((=:<=) x1 y1 d
    cs) ((&) ((=:<=) x2 y2 d cs) ((&) ((=:<=) x3 y3 d cs) ((=:<=) x4 y4 d cs) d
    cs) d cs) d cs
  (=.<=) a b cd _ = Fail_C_Success cd (unificationFail (showCons a) (showCons
    b))
  bind cd i (C_Node x3 x4 x5 x6) = (i :=: ChooseN 0 4) : concat [bind cd (leftID
    (leftID i)) x3, bind cd (rightID (leftID i)) x4, bind cd (leftID (rightID
    i)) x5, bind cd (rightID (rightID i)) x6]
  bind d i (Choice_C_Node cd j x y) = [ConstraintChoice cd j (bind d i x) (bind
    d i y)]
  bind d i (Choices_C_Node cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j xs
  bind d i (Choices_C_Node cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd j
    (map (bind d i) xs)]
  bind _ _ (Choices_C_Node cd i _) = error
    ("SCC.Node.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_Node cd info) = [Unsolvable info]
  bind d i (Guard_C_Node cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i (C_Node x3 x4 x5 x6) = (i :=: ChooseN 0 4) : [leftID (leftID
    i) :=: LazyBind (lazyBind cd (leftID (leftID i)) x3), rightID (leftID i) :=:
    LazyBind (lazyBind cd (rightID (leftID i)) x4), leftID (rightID i) :=:
    LazyBind (lazyBind cd (leftID (rightID i)) x5), rightID (rightID i) :=:
    LazyBind (lazyBind cd (rightID (rightID i)) x6)]
  lazyBind d i (Choice_C_Node cd j x y) = [ConstraintChoice cd j (lazyBind d i
    x) (lazyBind d i y)]
  lazyBind d i (Choices_C_Node cd j@(FreeID _ _) xs) = lazyBindOrNarrow d i cd j
    xs
  lazyBind d i (Choices_C_Node cd j@(NarrowedID _ _) xs) = [ConstraintChoices cd
    j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_Node cd i _) = error
    ("SCC.Node.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_Node cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_Node cd c e) = getConstrList c ++ [i :=: LazyBind
    (lazyBind d i e)]

instance (Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.Curry (C_Node t0 t1) where
  (=?=) (Choice_C_Node cd i x y) z d cs = narrow cd i ((Curry_Prelude.=?=) x z d
    cs) ((Curry_Prelude.=?=) y z d cs)
  (=?=) (Choices_C_Node cd i xs) y d cs = narrows cs cd i (\x ->
    (Curry_Prelude.=?=) x y d cs) xs
  (=?=) (Guard_C_Node cd c e) y d cs = guardCons cd c ((Curry_Prelude.=?=) e y d
    (addCs c cs))
  (=?=) (Fail_C_Node cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_Node cd i x y) d cs = narrow cd i ((Curry_Prelude.=?=) z x d
    cs) ((Curry_Prelude.=?=) z y d cs)
  (=?=) y (Choices_C_Node cd i xs) d cs = narrows cs cd i (\x ->
    (Curry_Prelude.=?=) y x d cs) xs
  (=?=) y (Guard_C_Node cd c e) d cs = guardCons cd c ((Curry_Prelude.=?=) y e d
    (addCs c cs))
  (=?=) _ (Fail_C_Node cd info) _ _ = failCons cd info
  (=?=) (C_Node x1 x2 x3 x4) (C_Node y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x2 y2 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x3 y3 d cs)
    ((Curry_Prelude.=?=) x4 y4 d cs) d cs) d cs) d cs
  (<?=) (Choice_C_Node cd i x y) z d cs = narrow cd i ((Curry_Prelude.<?=) x z d
    cs) ((Curry_Prelude.<?=) y z d cs)
  (<?=) (Choices_C_Node cd i xs) y d cs = narrows cs cd i (\x ->
    (Curry_Prelude.<?=) x y d cs) xs
  (<?=) (Guard_C_Node cd c e) y d cs = guardCons cd c ((Curry_Prelude.<?=) e y d
    (addCs c cs))
  (<?=) (Fail_C_Node cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_Node cd i x y) d cs = narrow cd i ((Curry_Prelude.<?=) z x d
    cs) ((Curry_Prelude.<?=) z y d cs)
  (<?=) y (Choices_C_Node cd i xs) d cs = narrows cs cd i (\x ->
    (Curry_Prelude.<?=) y x d cs) xs
  (<?=) y (Guard_C_Node cd c e) d cs = guardCons cd c ((Curry_Prelude.<?=) y e d
    (addCs c cs))
  (<?=) _ (Fail_C_Node cd info) _ _ = failCons cd info
  (<?=) (C_Node x1 x2 x3 x4) (C_Node y1 y2 y3 y4) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x1 y1 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x2 y2 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x2 y2 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x3 y3 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x3 y3 d cs)
    ((Curry_Prelude.<?=) x4 y4 d cs) d cs) d cs) d cs) d cs) d cs) d cs

d_C_cmpNode ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry t1) => C_Node t0 t1
  -> C_Node t0 t1 -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_cmpNode x1 x2 cd cs = Curry_Prelude.d_OP_lt (d_C_key x1 cd cs) (d_C_key x2
  cd cs) cd cs

d_C_key ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry t1) => C_Node t0 t1
  -> Cover -> ConstStore -> Curry_Prelude.C_Int
d_C_key x1 cd cs = case x1 of
  C_Node x2 x3 x4 x5 -> x2
  Choice_C_Node d i l r -> narrow d i (d_C_key l cd cs) (d_C_key r cd cs)
  Choices_C_Node d i xs -> narrows cs d i (\z -> d_C_key z cd cs) xs
  Guard_C_Node d c e -> guardCons d c (d_C_key e cd $! addCs c cs)
  Fail_C_Node d info -> failCons d (traceFail "SCC.key" [show x1] info)
  _ -> failCons cd (consFail "SCC.key" (showCons x1))

d_C_bvs ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry t1) => C_Node t0 t1
  -> Cover -> ConstStore -> Curry_Prelude.OP_List t1
d_C_bvs x1 cd cs = case x1 of
  C_Node x2 x3 x4 x5 -> x3
  Choice_C_Node d i l r -> narrow d i (d_C_bvs l cd cs) (d_C_bvs r cd cs)
  Choices_C_Node d i xs -> narrows cs d i (\z -> d_C_bvs z cd cs) xs
  Guard_C_Node d c e -> guardCons d c (d_C_bvs e cd $! addCs c cs)
  Fail_C_Node d info -> failCons d (traceFail "SCC.bvs" [show x1] info)
  _ -> failCons cd (consFail "SCC.bvs" (showCons x1))

d_C_fvs ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry t1) => C_Node t0 t1
  -> Cover -> ConstStore -> Curry_Prelude.OP_List t1
d_C_fvs x1 cd cs = case x1 of
  C_Node x2 x3 x4 x5 -> x4
  Choice_C_Node d i l r -> narrow d i (d_C_fvs l cd cs) (d_C_fvs r cd cs)
  Choices_C_Node d i xs -> narrows cs d i (\z -> d_C_fvs z cd cs) xs
  Guard_C_Node d c e -> guardCons d c (d_C_fvs e cd $! addCs c cs)
  Fail_C_Node d info -> failCons d (traceFail "SCC.fvs" [show x1] info)
  _ -> failCons cd (consFail "SCC.fvs" (showCons x1))

d_C_node ::(Curry_Prelude.Curry t1, Curry_Prelude.Curry t0) => C_Node t0 t1
  -> Cover -> ConstStore -> t0
d_C_node x1 cd cs = case x1 of
  C_Node x2 x3 x4 x5 -> x5
  Choice_C_Node d i l r -> narrow d i (d_C_node l cd cs) (d_C_node r cd cs)
  Choices_C_Node d i xs -> narrows cs d i (\z -> d_C_node z cd cs) xs
  Guard_C_Node d c e -> guardCons d c (d_C_node e cd $! addCs c cs)
  Fail_C_Node d info -> failCons d (traceFail "SCC.node" [show x1] info)
  _ -> failCons cd (consFail "SCC.node" (showCons x1))

d_C_scc ::(Curry_Prelude.Curry t1, Curry_Prelude.Curry t0) => (t0 -> Cover
  -> ConstStore -> Curry_Prelude.OP_List t1) -> (t0 -> Cover -> ConstStore
  -> Curry_Prelude.OP_List t1) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  t0 -> Cover -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List t0)
d_C_scc x1 x2 cd cs = Curry_Prelude.d_OP_dot (Curry_Prelude.d_C_map
  (Curry_Prelude.d_C_map d_C_node)) (Curry_Prelude.d_OP_dot d_C_tsort'
  (Curry_Prelude.d_OP_dot d_C_tsort (Curry_Prelude.d_C_zipWith (acceptCs id
  (d_OP_scc_dot_wrap_dot_24 x1 x2)) (Curry_Prelude.d_C_enumFrom
  (Curry_Prelude.C_Int 0#) cd cs)) cd cs) cd cs) cd cs

nd_C_scc ::(Curry_Prelude.Curry t1, Curry_Prelude.Curry t0) => Func t0
  (Curry_Prelude.OP_List t1) -> Func t0 (Curry_Prelude.OP_List t1) -> IDSupply
  -> Cover -> ConstStore -> Func (Curry_Prelude.OP_List t0)
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List t0))
nd_C_scc x1 x2 s cd cs = let s4 = s
  in s4 `seq` (let s3 = leftSupply s4
                   s2 = rightSupply s4
  in s3 `seq` (s2 `seq` Curry_Prelude.nd_OP_dot (wrapNX id
  (Curry_Prelude.nd_C_map (wrapNX id (Curry_Prelude.nd_C_map (wrapDX id
  d_C_node))))) (let s1 = leftSupply s2
                     s0 = rightSupply s2
  in s1 `seq` (s0 `seq` Curry_Prelude.nd_OP_dot (wrapDX id d_C_tsort')
  (Curry_Prelude.nd_OP_dot (wrapDX id d_C_tsort) (wrapNX id
  (Curry_Prelude.nd_C_zipWith (wrapDX (wrapNX id) (acceptCs id
  (nd_OP_scc_dot_wrap_dot_24 x1 x2))) (Curry_Prelude.d_C_enumFrom
  (Curry_Prelude.C_Int 0#) cd cs))) s0 cd cs) s1 cd cs)) s3 cd cs))

d_OP_scc_dot_wrap_dot_24 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => (t0 -> Cover -> ConstStore -> Curry_Prelude.OP_List t1) -> (t0 -> Cover
  -> ConstStore -> Curry_Prelude.OP_List t1) -> Curry_Prelude.C_Int -> t0
  -> Cover -> ConstStore -> C_Node t0 t1
d_OP_scc_dot_wrap_dot_24 x1 x2 x3 x4 cd cs = C_Node x3 (Curry_Prelude.d_C_apply
  x1 x4 cd cs) (Curry_Prelude.d_C_apply x2 x4 cd cs) x4

nd_OP_scc_dot_wrap_dot_24 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Func t0 (Curry_Prelude.OP_List t1) -> Func t0 (Curry_Prelude.OP_List
  t1) -> Curry_Prelude.C_Int -> t0 -> IDSupply -> Cover -> ConstStore -> C_Node
  t0 t1
nd_OP_scc_dot_wrap_dot_24 x1 x2 x3 x4 s cd cs = let s2 = s
  in s2 `seq` (let s0 = leftSupply s2
                   s1 = rightSupply s2
  in s0 `seq` (s1 `seq` C_Node x3 (Curry_Prelude.nd_C_apply x1 x4 s0 cd cs)
  (Curry_Prelude.nd_C_apply x2 x4 s1 cd cs) x4))

d_C_tsort ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (C_Node t0 t1)
d_C_tsort x1 cd cs = Curry_Prelude.d_C_snd (d_OP_tsort_dot_dfs_dot_29 x1 x1
  (Curry_Prelude.d_C_apply (Curry_SetRBT.d_C_emptySetRBT cd cs) (acceptCs id
  d_C_cmpNode) cd cs) Curry_Prelude.OP_List cd cs) cd cs

d_OP_tsort_dot_dfs_dot_29 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node
  t0 t1) -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1))
  (Curry_Prelude.OP_List (C_Node t0 t1))
d_OP_tsort_dot_dfs_dot_29 x1 x2 x3 x4 cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_Tuple2 x3 x4
  Curry_Prelude.OP_Cons x5 x6 -> let x7 = d_OP_tsort_dot_dfs_dot_29 x1
                                       (d_OP_tsort_dot_dfs_dot_29_dot_defs_dot_33
                                       x1 x5 cd cs) (Curry_Prelude.d_C_apply
                                       (Curry_Prelude.d_C_apply
                                       (Curry_SetRBT.d_C_insertRBT cd cs) x5 cd
                                       cs) x3 cd cs) x4 cd cs
                                     x8 = d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick
                                       x7 cd cs
                                     x9 = d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick
                                       x7 cd cs
    in d_C__case_3 x3 x5 x9 x8 x6 x1 x4 (Curry_Prelude.d_C_apply
    (Curry_SetRBT.d_C_elemRBT x5 cd cs) x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_OP_tsort_dot_dfs_dot_29
    x1 l x3 x4 cd cs) (d_OP_tsort_dot_dfs_dot_29 x1 r x3 x4 cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_tsort_dot_dfs_dot_29 x1 z x3 x4 cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_OP_tsort_dot_dfs_dot_29
    x1 e x3 x4 cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "SCC.tsort.dfs.29"
    [show x1, show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "SCC.tsort.dfs.29" (showCons x2))

nd_OP_tsort_dot_dfs_dot_29 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node
  t0 t1) -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1))
  (Curry_Prelude.OP_List (C_Node t0 t1))
nd_OP_tsort_dot_dfs_dot_29 x1 x2 x3 x4 s cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_Tuple2 x3 x4
  Curry_Prelude.OP_Cons x5 x6 -> let s14 = s
    in s14 `seq` (let s15 = leftSupply s14
                      s16 = rightSupply s14
                      s6 = leftSupply s15
                      s7 = rightSupply s15
                      s8 = leftSupply s16
                      s13 = rightSupply s16
    in s15 `seq` (s16 `seq` (s6 `seq` (s7 `seq` (s8 `seq` (s13 `seq`
    (let x7 = let s5 = leftSupply s6
                  s4 = rightSupply s6
           in s5 `seq` (s4 `seq` nd_OP_tsort_dot_dfs_dot_29 x1
           (d_OP_tsort_dot_dfs_dot_29_dot_defs_dot_33 x1 x5 cd cs)
           (let s3 = leftSupply s4
                s2 = rightSupply s4
           in s3 `seq` (s2 `seq` Curry_Prelude.nd_C_apply (let s1 = leftSupply
                                                                 s2
                                                               s0 = rightSupply
                                                                 s2
           in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply
           (Curry_SetRBT.nd_C_insertRBT s0 cd cs) x5 s1 cd cs)) x3 s3 cd cs)) x4
           s5 cd cs)
         x8 = nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick
           x7 s7 cd cs
         x9 = nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick
           x7 s8 cd cs
    in let s12 = leftSupply s13
           s11 = rightSupply s13
    in s12 `seq` (s11 `seq` nd_C__case_3 x3 x5 x9 x8 x6 x1 x4
    (let s10 = leftSupply s11
         s9 = rightSupply s11
    in s10 `seq` (s9 `seq` Curry_Prelude.nd_C_apply (Curry_SetRBT.nd_C_elemRBT
    x5 s9 cd cs) x3 s10 cd cs)) s12 cd cs))))))))
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_OP_tsort_dot_dfs_dot_29
    x1 l x3 x4 s cd cs) (nd_OP_tsort_dot_dfs_dot_29 x1 r x3 x4 s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    nd_OP_tsort_dot_dfs_dot_29 x1 z x3 x4 s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_OP_tsort_dot_dfs_dot_29
    x1 e x3 x4 s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "SCC.tsort.dfs.29"
    [show x1, show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "SCC.tsort.dfs.29" (showCons x2))

d_OP_tsort_dot_dfs_dot_29_dot_defs_dot_33 ::(Curry_Prelude.Curry t2
  , Curry_Prelude.Curry t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_List
  (C_Node t0 t1) -> C_Node t2 t1 -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (C_Node t0 t1)
d_OP_tsort_dot_dfs_dot_29_dot_defs_dot_33 x1 x2 cd cs = Curry_Prelude.d_C_filter
  (Curry_Prelude.d_OP_dot (Curry_Prelude.d_C_any (Curry_Prelude.d_C_flip
  Curry_Prelude.d_C_elem (d_C_fvs x2 cd cs)) cd cs) d_C_bvs cd cs) x1 cd cs

d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1)) -> Cover -> ConstStore -> Curry_RedBlackTree.C_RedBlackTree
  (C_Node t0 t1)
d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick l cd cs)
    (d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort.dfs.29._#selFP2#marks'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort.dfs.29._#selFP2#marks'" (showCons x1))

nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1)) -> IDSupply -> Cover -> ConstStore
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick x1 s cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick l s cd
    cs) (nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick r s
    cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick z s cd cs)
    xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP2_hash_marks_tick e s cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort.dfs.29._#selFP2#marks'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort.dfs.29._#selFP2#marks'" (showCons x1))

d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1)) -> Cover -> ConstStore -> Curry_Prelude.OP_List (C_Node t0 t1)
d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick l cd cs)
    (d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort.dfs.29._#selFP3#stack'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort.dfs.29._#selFP3#stack'" (showCons x1))

nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1)) -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (C_Node t0 t1)
nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick x1 s cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick l s cd
    cs) (nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick r s
    cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick z s cd cs)
    xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_tsort_dot_dfs_dot_29_dot_uscore_hash_selFP3_hash_stack_tick e s cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort.dfs.29._#selFP3#stack'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort.dfs.29._#selFP3#stack'" (showCons x1))

d_C_tsort' ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
d_C_tsort' x1 cd cs = Curry_Prelude.d_C_snd (d_OP_tsort_tick_dot_dfs_dot_38 x1
  x1 (Curry_Prelude.d_C_apply (Curry_SetRBT.d_C_emptySetRBT cd cs) (acceptCs id
  d_C_cmpNode) cd cs) Curry_Prelude.OP_List cd cs) cd cs

d_OP_tsort_tick_dot_dfs_dot_38 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node
  t0 t1) -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_RedBlackTree.C_RedBlackTree
  (C_Node t0 t1)) (Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1)))
d_OP_tsort_tick_dot_dfs_dot_38 x1 x2 x3 x4 cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_Tuple2 x3 x4
  Curry_Prelude.OP_Cons x5 x6 -> let x7 = d_OP_tsort_tick_dot_dfs_dot_38 x1
                                       (d_OP_tsort_tick_dot_dfs_dot_38_dot_uses_dot_42
                                       x1 x5 cd cs) (Curry_Prelude.d_C_apply
                                       (Curry_Prelude.d_C_apply
                                       (Curry_SetRBT.d_C_insertRBT cd cs) x5 cd
                                       cs) x3 cd cs) Curry_Prelude.OP_List cd cs
                                     x8 = d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick
                                       x7 cd cs
                                     x9 = d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick
                                       x7 cd cs
    in d_C__case_1 x3 x5 x4 x9 x8 x6 x1 (Curry_Prelude.d_C_apply
    (Curry_SetRBT.d_C_elemRBT x5 cd cs) x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_tsort_tick_dot_dfs_dot_38 x1 l x3 x4 cd cs)
    (d_OP_tsort_tick_dot_dfs_dot_38 x1 r x3 x4 cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_tsort_tick_dot_dfs_dot_38 x1 z x3 x4 cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_tsort_tick_dot_dfs_dot_38 x1 e x3 x4 cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "SCC.tsort'.dfs.38"
    [show x1, show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "SCC.tsort'.dfs.38" (showCons x2))

nd_OP_tsort_tick_dot_dfs_dot_38 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node
  t0 t1) -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1)) -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1)))
nd_OP_tsort_tick_dot_dfs_dot_38 x1 x2 x3 x4 s cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_Tuple2 x3 x4
  Curry_Prelude.OP_Cons x5 x6 -> let s14 = s
    in s14 `seq` (let s15 = leftSupply s14
                      s16 = rightSupply s14
                      s6 = leftSupply s15
                      s7 = rightSupply s15
                      s8 = leftSupply s16
                      s13 = rightSupply s16
    in s15 `seq` (s16 `seq` (s6 `seq` (s7 `seq` (s8 `seq` (s13 `seq`
    (let x7 = let s5 = leftSupply s6
                  s4 = rightSupply s6
           in s5 `seq` (s4 `seq` nd_OP_tsort_tick_dot_dfs_dot_38 x1
           (d_OP_tsort_tick_dot_dfs_dot_38_dot_uses_dot_42 x1 x5 cd cs)
           (let s3 = leftSupply s4
                s2 = rightSupply s4
           in s3 `seq` (s2 `seq` Curry_Prelude.nd_C_apply (let s1 = leftSupply
                                                                 s2
                                                               s0 = rightSupply
                                                                 s2
           in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply
           (Curry_SetRBT.nd_C_insertRBT s0 cd cs) x5 s1 cd cs)) x3 s3 cd cs))
           Curry_Prelude.OP_List s5 cd cs)
         x8 = nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick
           x7 s7 cd cs
         x9 = nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick
           x7 s8 cd cs
    in let s12 = leftSupply s13
           s11 = rightSupply s13
    in s12 `seq` (s11 `seq` nd_C__case_1 x3 x5 x4 x9 x8 x6 x1
    (let s10 = leftSupply s11
         s9 = rightSupply s11
    in s10 `seq` (s9 `seq` Curry_Prelude.nd_C_apply (Curry_SetRBT.nd_C_elemRBT
    x5 s9 cd cs) x3 s10 cd cs)) s12 cd cs))))))))
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (nd_OP_tsort_tick_dot_dfs_dot_38 x1 l x3 x4 s cd cs)
    (nd_OP_tsort_tick_dot_dfs_dot_38 x1 r x3 x4 s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    nd_OP_tsort_tick_dot_dfs_dot_38 x1 z x3 x4 s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (nd_OP_tsort_tick_dot_dfs_dot_38 x1 e x3 x4 s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "SCC.tsort'.dfs.38"
    [show x1, show x2, show x3, show x4] info)
  _ -> failCons cd (consFail "SCC.tsort'.dfs.38" (showCons x2))

d_OP_tsort_tick_dot_dfs_dot_38_dot_uses_dot_42 ::(Curry_Prelude.Curry t2
  , Curry_Prelude.Curry t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_List
  (C_Node t0 t1) -> C_Node t2 t1 -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (C_Node t0 t1)
d_OP_tsort_tick_dot_dfs_dot_38_dot_uses_dot_42 x1 x2 cd cs =
  Curry_Prelude.d_C_filter (Curry_Prelude.d_OP_dot (Curry_Prelude.d_C_any
  (Curry_Prelude.d_C_flip Curry_Prelude.d_C_elem (d_C_bvs x2 cd cs)) cd cs)
  d_C_fvs cd cs) x1 cd cs

d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1))) -> Cover -> ConstStore
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick l cd
    cs) (d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick r
    cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick z cd
    cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort'.dfs.38._#selFP5#marks'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort'.dfs.38._#selFP5#marks'" (showCons x1))

nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1))) -> IDSupply -> Cover -> ConstStore
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick x1 s cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick l s
    cd cs)
    (nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick r s
    cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick z s
    cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP5_hash_marks_tick e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort'.dfs.38._#selFP5#marks'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort'.dfs.38._#selFP5#marks'" (showCons x1))

d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1))) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick l cd
    cs) (d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick r
    cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick z cd
    cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort'.dfs.38._#selFP6#stack'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort'.dfs.38._#selFP6#stack'" (showCons x1))

nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick ::(Curry_Prelude.Curry
  t0, Curry_Prelude.Curry t1) => Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1))) -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick x1 s cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick l s
    cd cs)
    (nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick r s
    cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick z s
    cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (nd_OP_tsort_tick_dot_dfs_dot_38_dot_uscore_hash_selFP6_hash_stack_tick e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "SCC.tsort'.dfs.38._#selFP6#stack'" [show x1] info)
  _ -> failCons cd (consFail "SCC.tsort'.dfs.38._#selFP6#stack'" (showCons x1))

d_C__case_1 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> C_Node t0 t1
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> Curry_Prelude.OP_List
  (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1)))
d_C__case_1 x3 x5 x4 x9 x8 x6 x1 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> d_OP_tsort_tick_dot_dfs_dot_38 x1 x6 x3 x4 cd cs
  Curry_Prelude.C_False -> d_C__case_0 x4 x9 x5 x8 x6 x1
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 x3 x5 x4 x9 x8
    x6 x1 l cd cs) (d_C__case_1 x3 x5 x4 x9 x8 x6 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 x3 x5
    x4 x9 x8 x6 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_1 x3 x5 x4 x9 x8
    x6 x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_1" [show
    x3, show x5, show x4, show x9, show x8, show x6, show x1, show x10] info)
  _ -> failCons cd (consFail "SCC._case_1" (showCons x10))

nd_C__case_1 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> C_Node t0 t1
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> Curry_Prelude.OP_List
  (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1)))
nd_C__case_1 x3 x5 x4 x9 x8 x6 x1 x10 s cd cs = case x10 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_OP_tsort_tick_dot_dfs_dot_38 x1 x6 x3 x4 s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_0 x4 x9 x5 x8 x6 x1 (Curry_Prelude.d_C_otherwise cd
    cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_1 x3 x5 x4 x9 x8
    x6 x1 l s cd cs) (nd_C__case_1 x3 x5 x4 x9 x8 x6 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_1 x3
    x5 x4 x9 x8 x6 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_1 x3 x5 x4 x9 x8
    x6 x1 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_1" [show
    x3, show x5, show x4, show x9, show x8, show x6, show x1, show x10] info)
  _ -> failCons cd (consFail "SCC._case_1" (showCons x10))

d_C__case_0 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1)) -> C_Node t0
  t1 -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0
  t1) -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (C_Node t0 t1)))
d_C__case_0 x4 x9 x5 x8 x6 x1 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> d_OP_tsort_tick_dot_dfs_dot_38 x1 x6 x8
    (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Cons x5 (Curry_Prelude.d_C_concat
    x9 cd cs)) x4) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_0 x4 x9 x5 x8 x6
    x1 l cd cs) (d_C__case_0 x4 x9 x5 x8 x6 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_0 x4 x9
    x5 x8 x6 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_0 x4 x9 x5 x8 x6
    x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_0" [show
    x4, show x9, show x5, show x8, show x6, show x1, show x10] info)
  _ -> failCons cd (consFail "SCC._case_0" (showCons x10))

nd_C__case_0 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1)) -> C_Node t0
  t1 -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0
  t1) -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List (C_Node t0 t1)))
nd_C__case_0 x4 x9 x5 x8 x6 x1 x10 s cd cs = case x10 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_OP_tsort_tick_dot_dfs_dot_38 x1 x6 x8 (Curry_Prelude.OP_Cons
    (Curry_Prelude.OP_Cons x5 (Curry_Prelude.d_C_concat x9 cd cs)) x4) s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_0 x4 x9 x5 x8 x6
    x1 l s cd cs) (nd_C__case_0 x4 x9 x5 x8 x6 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_0 x4
    x9 x5 x8 x6 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_0 x4 x9 x5 x8 x6
    x1 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_0" [show
    x4, show x9, show x5, show x8, show x6, show x1, show x10] info)
  _ -> failCons cd (consFail "SCC._case_0" (showCons x10))

d_C__case_3 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> C_Node t0 t1
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_RedBlackTree.C_RedBlackTree
  (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0 t1)
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0
  t1) -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1))
d_C__case_3 x3 x5 x9 x8 x6 x1 x4 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> d_OP_tsort_dot_dfs_dot_29 x1 x6 x3 x4 cd cs
  Curry_Prelude.C_False -> d_C__case_2 x9 x5 x8 x6 x1
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x3 x5 x9 x8 x6
    x1 x4 l cd cs) (d_C__case_3 x3 x5 x9 x8 x6 x1 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x3 x5
    x9 x8 x6 x1 x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_3 x3 x5 x9 x8 x6
    x1 x4 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_3" [show
    x3, show x5, show x9, show x8, show x6, show x1, show x4, show x10] info)
  _ -> failCons cd (consFail "SCC._case_3" (showCons x10))

nd_C__case_3 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> C_Node t0 t1
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_RedBlackTree.C_RedBlackTree
  (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0 t1)
  -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0
  t1) -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1))
  (Curry_Prelude.OP_List (C_Node t0 t1))
nd_C__case_3 x3 x5 x9 x8 x6 x1 x4 x10 s cd cs = case x10 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_OP_tsort_dot_dfs_dot_29 x1 x6 x3 x4 s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_2 x9 x5 x8 x6 x1 (Curry_Prelude.d_C_otherwise cd cs)
    s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_3 x3 x5 x9 x8 x6
    x1 x4 l s cd cs) (nd_C__case_3 x3 x5 x9 x8 x6 x1 x4 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_3 x3
    x5 x9 x8 x6 x1 x4 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_3 x3 x5 x9 x8 x6
    x1 x4 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_3" [show
    x3, show x5, show x9, show x8, show x6, show x1, show x4, show x10] info)
  _ -> failCons cd (consFail "SCC._case_3" (showCons x10))

d_C__case_2 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> C_Node t0 t1
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> Curry_Prelude.OP_List
  (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1))
d_C__case_2 x9 x5 x8 x6 x1 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> d_OP_tsort_dot_dfs_dot_29 x1 x6 x8
    (Curry_Prelude.OP_Cons x5 x9) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x9 x5 x8 x6 x1
    l cd cs) (d_C__case_2 x9 x5 x8 x6 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x9 x5
    x8 x6 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_2 x9 x5 x8 x6 x1
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_2" [show
    x9, show x5, show x8, show x6, show x1, show x10] info)
  _ -> failCons cd (consFail "SCC._case_2" (showCons x10))

nd_C__case_2 ::(Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1) => Curry_Prelude.OP_List (C_Node t0 t1) -> C_Node t0 t1
  -> Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1) -> Curry_Prelude.OP_List
  (C_Node t0 t1) -> Curry_Prelude.OP_List (C_Node t0 t1) -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_RedBlackTree.C_RedBlackTree (C_Node t0 t1)) (Curry_Prelude.OP_List
  (C_Node t0 t1))
nd_C__case_2 x9 x5 x8 x6 x1 x10 s cd cs = case x10 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_OP_tsort_dot_dfs_dot_29 x1 x6 x8 (Curry_Prelude.OP_Cons x5
    x9) s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_2 x9 x5 x8 x6 x1
    l s cd cs) (nd_C__case_2 x9 x5 x8 x6 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_2 x9
    x5 x8 x6 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_2 x9 x5 x8 x6 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "SCC._case_2" [show
    x9, show x5, show x8, show x6, show x1, show x10] info)
  _ -> failCons cd (consFail "SCC._case_2" (showCons x10))

