{-# LANGUAGE MagicHash #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Curry_Distribution
  ( C_FrontendTarget (..), C_FrontendParams (..), d_C_rcFileName
  , d_C_rcFileContents, d_C_getRcVar, d_C_getRcVars, d_C_splitModuleFileName
  , d_C_splitModuleIdentifiers, d_C_joinModuleIdentifiers, d_C_stripCurrySuffix
  , d_C_modNameToPath, d_C_currySubdir, d_C_inCurrySubdir
  , d_C_inCurrySubdirModule, d_C_addCurrySubdir, d_C_lookupFileInLoadPath
  , d_C_findFileInLoadPath, d_C_readFirstFileInLoadPath, d_C_getLoadPath
  , d_C_getLoadPathForFile, d_C_getLoadPathForModule
  , d_C_lookupModuleSourceInLoadPath, d_C_defaultParams, d_C_rcParams
  , d_C_setQuiet, d_C_setExtended, d_C_setOverlapWarn, d_C_setFullPath
  , d_C_setHtmlDir, d_C_setLogfile, d_C_setSpecials, d_C_quiet, d_C_extended
  , d_C_overlapWarn, d_C_fullPath, d_C_htmldir, d_C_logfile, d_C_specials
  , d_C_callFrontend, d_C_callFrontendWithParams, d_C_curryCompiler
  , d_C_curryCompilerMajorVersion, d_C_curryCompilerMinorVersion
  , d_C_curryRuntime, d_C_curryRuntimeMajorVersion, d_C_curryRuntimeMinorVersion
  , d_C_installDir )
  where

import Basics
import qualified Curry_Char
import qualified Curry_Directory
import qualified Curry_FileGoodies
import qualified Curry_FilePath
import qualified Curry_IO
import qualified Curry_List
import qualified Curry_Prelude
import qualified Curry_PropertyFile
import qualified Curry_System

import qualified Installation as I

type C_ModuleIdent = Curry_Prelude.OP_List Curry_Prelude.C_Char

type C_ModulePath = Curry_Prelude.OP_List Curry_Prelude.C_Char

data C_FrontendTarget
  = C_FCY
  | C_FINT
  | C_ACY
  | C_UACY
  | C_HTML
  | C_CY
  | Choice_C_FrontendTarget Cover ID C_FrontendTarget C_FrontendTarget
  | Choices_C_FrontendTarget Cover ID [C_FrontendTarget]
  | Fail_C_FrontendTarget Cover FailInfo
  | Guard_C_FrontendTarget Cover Constraints C_FrontendTarget

instance Show C_FrontendTarget where
  showsPrec d (Choice_C_FrontendTarget cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_FrontendTarget cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_FrontendTarget cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_FrontendTarget cd info) = showChar '!'
  showsPrec _ C_FCY = showString "FCY"
  showsPrec _ C_FINT = showString "FINT"
  showsPrec _ C_ACY = showString "ACY"
  showsPrec _ C_UACY = showString "UACY"
  showsPrec _ C_HTML = showString "HTML"
  showsPrec _ C_CY = showString "CY"

instance Read C_FrontendTarget where
  readsPrec _ s = readParen False (\r -> [(C_FCY, r0) | (_, r0) <- readQualified
    "Distribution" "FCY" r]) s ++ (readParen False (\r -> [(C_FINT, r0) | (_
    , r0) <- readQualified "Distribution" "FINT" r]) s ++ (readParen False
    (\r -> [(C_ACY, r0) | (_, r0) <- readQualified "Distribution" "ACY" r]) s ++
    (readParen False (\r -> [(C_UACY, r0) | (_, r0) <- readQualified
    "Distribution" "UACY" r]) s ++ (readParen False (\r -> [(C_HTML, r0) | (_
    , r0) <- readQualified "Distribution" "HTML" r]) s ++ readParen False (\r ->
    [(C_CY, r0) | (_, r0) <- readQualified "Distribution" "CY" r]) s))))

instance NonDet C_FrontendTarget where
  choiceCons = Choice_C_FrontendTarget
  choicesCons = Choices_C_FrontendTarget
  failCons = Fail_C_FrontendTarget
  guardCons = Guard_C_FrontendTarget
  try (Choice_C_FrontendTarget cd i x y) = tryChoice cd i x y
  try (Choices_C_FrontendTarget cd i xs) = tryChoices cd i xs
  try (Fail_C_FrontendTarget cd info) = Fail cd info
  try (Guard_C_FrontendTarget cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_FrontendTarget cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_FrontendTarget cd i@(NarrowedID _ _) xs) = f cd i
    xs
  match _ _ f _ _ _ (Choices_C_FrontendTarget cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_FrontendTarget cd i _) = error
    ("Distribution.FrontendTarget.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_FrontendTarget cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_FrontendTarget cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance Generable C_FrontendTarget where
  generate s c = Choices_C_FrontendTarget c (freeID [0, 0, 0, 0, 0, 0] s) [C_FCY
    , C_FINT, C_ACY, C_UACY, C_HTML, C_CY]

instance NormalForm C_FrontendTarget where
  ($!!) cont C_FCY d cs = cont C_FCY d cs
  ($!!) cont C_FINT d cs = cont C_FINT d cs
  ($!!) cont C_ACY d cs = cont C_ACY d cs
  ($!!) cont C_UACY d cs = cont C_UACY d cs
  ($!!) cont C_HTML d cs = cont C_HTML d cs
  ($!!) cont C_CY d cs = cont C_CY d cs
  ($!!) cont (Choice_C_FrontendTarget cd i x y) d cs = nfChoice cont cd i x y cd
    cs
  ($!!) cont (Choices_C_FrontendTarget cd i xs) d cs = nfChoices cont cd i xs d
    cs
  ($!!) cont (Guard_C_FrontendTarget cd c e) d cs = guardCons cd c (($!!) cont e
    d (addCs c cs))
  ($!!) _ (Fail_C_FrontendTarget cd info) _ _ = failCons cd info
  ($##) cont C_FCY d cs = cont C_FCY d cs
  ($##) cont C_FINT d cs = cont C_FINT d cs
  ($##) cont C_ACY d cs = cont C_ACY d cs
  ($##) cont C_UACY d cs = cont C_UACY d cs
  ($##) cont C_HTML d cs = cont C_HTML d cs
  ($##) cont C_CY d cs = cont C_CY d cs
  ($##) cont (Choice_C_FrontendTarget cd i x y) d cs = gnfChoice cont cd i x y
    cd cs
  ($##) cont (Choices_C_FrontendTarget cd i xs) d cs = gnfChoices cont cd i xs d
    cs
  ($##) cont (Guard_C_FrontendTarget cd c e) d cs = guardCons cd c (($##) cont e
    d (addCs c cs))
  ($##) _ (Fail_C_FrontendTarget cd info) _ _ = failCons cd info
  showCons C_FCY = "Distribution.FCY"
  showCons C_FINT = "Distribution.FINT"
  showCons C_ACY = "Distribution.ACY"
  showCons C_UACY = "Distribution.UACY"
  showCons C_HTML = "Distribution.HTML"
  showCons C_CY = "Distribution.CY"
  showCons x = error
    ("Distribution.FrontendTarget.showCons: no constructor: " ++ show x)
  searchNF _ cont C_FCY = cont C_FCY
  searchNF _ cont C_FINT = cont C_FINT
  searchNF _ cont C_ACY = cont C_ACY
  searchNF _ cont C_UACY = cont C_UACY
  searchNF _ cont C_HTML = cont C_HTML
  searchNF _ cont C_CY = cont C_CY
  searchNF _ _ x = error
    ("Distribution.FrontendTarget.searchNF: no constructor: " ++ show x)

instance Unifiable C_FrontendTarget where
  (=.=) C_FCY C_FCY d cs = C_Success
  (=.=) C_FINT C_FINT d cs = C_Success
  (=.=) C_ACY C_ACY d cs = C_Success
  (=.=) C_UACY C_UACY d cs = C_Success
  (=.=) C_HTML C_HTML d cs = C_Success
  (=.=) C_CY C_CY d cs = C_Success
  (=.=) a b cd _ = Fail_C_Success cd (unificationFail (showCons a) (showCons b))
  (=.<=) C_FCY C_FCY d cs = C_Success
  (=.<=) C_FINT C_FINT d cs = C_Success
  (=.<=) C_ACY C_ACY d cs = C_Success
  (=.<=) C_UACY C_UACY d cs = C_Success
  (=.<=) C_HTML C_HTML d cs = C_Success
  (=.<=) C_CY C_CY d cs = C_Success
  (=.<=) a b cd _ = Fail_C_Success cd (unificationFail (showCons a) (showCons
    b))
  bind cd i C_FCY = (i :=: ChooseN 0 0) : concat []
  bind cd i C_FINT = (i :=: ChooseN 1 0) : concat []
  bind cd i C_ACY = (i :=: ChooseN 2 0) : concat []
  bind cd i C_UACY = (i :=: ChooseN 3 0) : concat []
  bind cd i C_HTML = (i :=: ChooseN 4 0) : concat []
  bind cd i C_CY = (i :=: ChooseN 5 0) : concat []
  bind d i (Choice_C_FrontendTarget cd j x y) = [ConstraintChoice cd j (bind d i
    x) (bind d i y)]
  bind d i (Choices_C_FrontendTarget cd j@(FreeID _ _) xs) = bindOrNarrow d i cd
    j xs
  bind d i (Choices_C_FrontendTarget cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (bind d i) xs)]
  bind _ _ (Choices_C_FrontendTarget cd i _) = error
    ("Distribution.FrontendTarget.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_FrontendTarget cd info) = [Unsolvable info]
  bind d i (Guard_C_FrontendTarget cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i C_FCY = (i :=: ChooseN 0 0) : []
  lazyBind cd i C_FINT = (i :=: ChooseN 1 0) : []
  lazyBind cd i C_ACY = (i :=: ChooseN 2 0) : []
  lazyBind cd i C_UACY = (i :=: ChooseN 3 0) : []
  lazyBind cd i C_HTML = (i :=: ChooseN 4 0) : []
  lazyBind cd i C_CY = (i :=: ChooseN 5 0) : []
  lazyBind d i (Choice_C_FrontendTarget cd j x y) = [ConstraintChoice cd j
    (lazyBind d i x) (lazyBind d i y)]
  lazyBind d i (Choices_C_FrontendTarget cd j@(FreeID _ _) xs) =
    lazyBindOrNarrow d i cd j xs
  lazyBind d i (Choices_C_FrontendTarget cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_FrontendTarget cd i _) = error
    ("Distribution.FrontendTarget.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_FrontendTarget cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_FrontendTarget cd c e) = getConstrList c ++ [i :=:
    LazyBind (lazyBind d i e)]

instance Curry_Prelude.Curry C_FrontendTarget where
  (=?=) (Choice_C_FrontendTarget cd i x y) z d cs = narrow cd i
    ((Curry_Prelude.=?=) x z d cs) ((Curry_Prelude.=?=) y z d cs)
  (=?=) (Choices_C_FrontendTarget cd i xs) y d cs = narrows cs cd i (\x ->
    (Curry_Prelude.=?=) x y d cs) xs
  (=?=) (Guard_C_FrontendTarget cd c e) y d cs = guardCons cd c
    ((Curry_Prelude.=?=) e y d (addCs c cs))
  (=?=) (Fail_C_FrontendTarget cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_FrontendTarget cd i x y) d cs = narrow cd i
    ((Curry_Prelude.=?=) z x d cs) ((Curry_Prelude.=?=) z y d cs)
  (=?=) y (Choices_C_FrontendTarget cd i xs) d cs = narrows cs cd i (\x ->
    (Curry_Prelude.=?=) y x d cs) xs
  (=?=) y (Guard_C_FrontendTarget cd c e) d cs = guardCons cd c
    ((Curry_Prelude.=?=) y e d (addCs c cs))
  (=?=) _ (Fail_C_FrontendTarget cd info) _ _ = failCons cd info
  (=?=) C_FCY C_FCY d cs = Curry_Prelude.C_True
  (=?=) C_FINT C_FINT d cs = Curry_Prelude.C_True
  (=?=) C_ACY C_ACY d cs = Curry_Prelude.C_True
  (=?=) C_UACY C_UACY d cs = Curry_Prelude.C_True
  (=?=) C_HTML C_HTML d cs = Curry_Prelude.C_True
  (=?=) C_CY C_CY d cs = Curry_Prelude.C_True
  (=?=) _ _ d _ = Curry_Prelude.C_False
  (<?=) (Choice_C_FrontendTarget cd i x y) z d cs = narrow cd i
    ((Curry_Prelude.<?=) x z d cs) ((Curry_Prelude.<?=) y z d cs)
  (<?=) (Choices_C_FrontendTarget cd i xs) y d cs = narrows cs cd i (\x ->
    (Curry_Prelude.<?=) x y d cs) xs
  (<?=) (Guard_C_FrontendTarget cd c e) y d cs = guardCons cd c
    ((Curry_Prelude.<?=) e y d (addCs c cs))
  (<?=) (Fail_C_FrontendTarget cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_FrontendTarget cd i x y) d cs = narrow cd i
    ((Curry_Prelude.<?=) z x d cs) ((Curry_Prelude.<?=) z y d cs)
  (<?=) y (Choices_C_FrontendTarget cd i xs) d cs = narrows cs cd i (\x ->
    (Curry_Prelude.<?=) y x d cs) xs
  (<?=) y (Guard_C_FrontendTarget cd c e) d cs = guardCons cd c
    ((Curry_Prelude.<?=) y e d (addCs c cs))
  (<?=) _ (Fail_C_FrontendTarget cd info) _ _ = failCons cd info
  (<?=) C_FCY C_FCY d cs = Curry_Prelude.C_True
  (<?=) C_FCY C_FINT _ _ = Curry_Prelude.C_True
  (<?=) C_FCY C_ACY _ _ = Curry_Prelude.C_True
  (<?=) C_FCY C_UACY _ _ = Curry_Prelude.C_True
  (<?=) C_FCY C_HTML _ _ = Curry_Prelude.C_True
  (<?=) C_FCY C_CY _ _ = Curry_Prelude.C_True
  (<?=) C_FINT C_FINT d cs = Curry_Prelude.C_True
  (<?=) C_FINT C_ACY _ _ = Curry_Prelude.C_True
  (<?=) C_FINT C_UACY _ _ = Curry_Prelude.C_True
  (<?=) C_FINT C_HTML _ _ = Curry_Prelude.C_True
  (<?=) C_FINT C_CY _ _ = Curry_Prelude.C_True
  (<?=) C_ACY C_ACY d cs = Curry_Prelude.C_True
  (<?=) C_ACY C_UACY _ _ = Curry_Prelude.C_True
  (<?=) C_ACY C_HTML _ _ = Curry_Prelude.C_True
  (<?=) C_ACY C_CY _ _ = Curry_Prelude.C_True
  (<?=) C_UACY C_UACY d cs = Curry_Prelude.C_True
  (<?=) C_UACY C_HTML _ _ = Curry_Prelude.C_True
  (<?=) C_UACY C_CY _ _ = Curry_Prelude.C_True
  (<?=) C_HTML C_HTML d cs = Curry_Prelude.C_True
  (<?=) C_HTML C_CY _ _ = Curry_Prelude.C_True
  (<?=) C_CY C_CY d cs = Curry_Prelude.C_True
  (<?=) _ _ d _ = Curry_Prelude.C_False

data C_FrontendParams
  = C_FrontendParams Curry_Prelude.C_Bool Curry_Prelude.C_Bool
    Curry_Prelude.C_Bool (Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
    (Curry_Prelude.OP_List Curry_Prelude.C_Char))) (Curry_Prelude.C_Maybe
    (Curry_Prelude.OP_List Curry_Prelude.C_Char)) (Curry_Prelude.C_Maybe
    (Curry_Prelude.OP_List Curry_Prelude.C_Char)) (Curry_Prelude.OP_List
    Curry_Prelude.C_Char)
  | Choice_C_FrontendParams Cover ID C_FrontendParams C_FrontendParams
  | Choices_C_FrontendParams Cover ID [C_FrontendParams]
  | Fail_C_FrontendParams Cover FailInfo
  | Guard_C_FrontendParams Cover Constraints C_FrontendParams

instance Show C_FrontendParams where
  showsPrec d (Choice_C_FrontendParams cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_FrontendParams cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_FrontendParams cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_FrontendParams cd info) = showChar '!'
  showsPrec _ (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) = showString
    "(FrontendParams" . (showChar ' ' . (shows x1 . (showChar ' ' . (shows x2 .
    (showChar ' ' . (shows x3 . (showChar ' ' . (shows x4 . (showChar ' ' .
    (shows x5 . (showChar ' ' . (shows x6 . (showChar ' ' . (shows x7 . showChar
    ')'))))))))))))))

instance Read C_FrontendParams where
  readsPrec d s = readParen ((>) d 10) (\r -> [(C_FrontendParams x1 x2 x3 x4 x5
    x6 x7, r7) | (_, r0) <- readQualified "Distribution" "FrontendParams" r, (x1
    , r1) <- readsPrec 11 r0, (x2, r2) <- readsPrec 11 r1, (x3, r3) <- readsPrec
    11 r2, (x4, r4) <- readsPrec 11 r3, (x5, r5) <- readsPrec 11 r4, (x6, r6) <-
    readsPrec 11 r5, (x7, r7) <- readsPrec 11 r6]) s

instance NonDet C_FrontendParams where
  choiceCons = Choice_C_FrontendParams
  choicesCons = Choices_C_FrontendParams
  failCons = Fail_C_FrontendParams
  guardCons = Guard_C_FrontendParams
  try (Choice_C_FrontendParams cd i x y) = tryChoice cd i x y
  try (Choices_C_FrontendParams cd i xs) = tryChoices cd i xs
  try (Fail_C_FrontendParams cd info) = Fail cd info
  try (Guard_C_FrontendParams cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_FrontendParams cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_FrontendParams cd i@(NarrowedID _ _) xs) = f cd i
    xs
  match _ _ f _ _ _ (Choices_C_FrontendParams cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_FrontendParams cd i _) = error
    ("Distribution.FrontendParams.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_FrontendParams cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_FrontendParams cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance Generable C_FrontendParams where
  generate s c = Choices_C_FrontendParams c (freeID [7] s) [C_FrontendParams
    (generate (leftSupply (leftSupply (leftSupply s))) c) (generate (rightSupply
    (leftSupply (leftSupply s))) c) (generate (leftSupply (rightSupply
    (leftSupply s))) c) (generate (rightSupply (rightSupply (leftSupply s))) c)
    (generate (leftSupply (leftSupply (rightSupply s))) c) (generate
    (rightSupply (leftSupply (rightSupply s))) c) (generate (rightSupply
    (rightSupply s)) c)]

instance NormalForm C_FrontendParams where
  ($!!) cont (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) d cs = ($!!) (\y1 d cs ->
    ($!!) (\y2 d cs -> ($!!) (\y3 d cs -> ($!!) (\y4 d cs -> ($!!) (\y5 d cs ->
    ($!!) (\y6 d cs -> ($!!) (\y7 d cs -> cont (C_FrontendParams y1 y2 y3 y4 y5
    y6 y7) d cs) x7 d cs) x6 d cs) x5 d cs) x4 d cs) x3 d cs) x2 d cs) x1 d cs
  ($!!) cont (Choice_C_FrontendParams cd i x y) d cs = nfChoice cont cd i x y cd
    cs
  ($!!) cont (Choices_C_FrontendParams cd i xs) d cs = nfChoices cont cd i xs d
    cs
  ($!!) cont (Guard_C_FrontendParams cd c e) d cs = guardCons cd c (($!!) cont e
    d (addCs c cs))
  ($!!) _ (Fail_C_FrontendParams cd info) _ _ = failCons cd info
  ($##) cont (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) d cs = ($##) (\y1 d cs ->
    ($##) (\y2 d cs -> ($##) (\y3 d cs -> ($##) (\y4 d cs -> ($##) (\y5 d cs ->
    ($##) (\y6 d cs -> ($##) (\y7 d cs -> cont (C_FrontendParams y1 y2 y3 y4 y5
    y6 y7) d cs) x7 d cs) x6 d cs) x5 d cs) x4 d cs) x3 d cs) x2 d cs) x1 d cs
  ($##) cont (Choice_C_FrontendParams cd i x y) d cs = gnfChoice cont cd i x y
    cd cs
  ($##) cont (Choices_C_FrontendParams cd i xs) d cs = gnfChoices cont cd i xs d
    cs
  ($##) cont (Guard_C_FrontendParams cd c e) d cs = guardCons cd c (($##) cont e
    d (addCs c cs))
  ($##) _ (Fail_C_FrontendParams cd info) _ _ = failCons cd info
  showCons (C_FrontendParams _ _ _ _ _ _ _) =
    "Distribution.FrontendParams _ _ _ _ _ _ _"
  showCons x = error
    ("Distribution.FrontendParams.showCons: no constructor: " ++ show x)
  searchNF search cont (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) = search (\y1 ->
    search (\y2 -> search (\y3 -> search (\y4 -> search (\y5 -> search (\y6 ->
    search (\y7 -> cont (C_FrontendParams y1 y2 y3 y4 y5 y6 y7)) x7) x6) x5) x4)
    x3) x2) x1
  searchNF _ _ x = error
    ("Distribution.FrontendParams.searchNF: no constructor: " ++ show x)

instance Unifiable C_FrontendParams where
  (=.=) (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) (C_FrontendParams y1 y2 y3 y4 y5 y6 y7) d cs =
    (&) ((=:=) x1 y1 d cs) ((&) ((=:=) x2 y2 d cs) ((&) ((=:=) x3 y3 d cs) ((&)
    ((=:=) x4 y4 d cs) ((&) ((=:=) x5 y5 d cs) ((&) ((=:=) x6 y6 d cs) ((=:=) x7
    y7 d cs) d cs) d cs) d cs) d cs) d cs) d cs
  (=.=) a b cd _ = Fail_C_Success cd (unificationFail (showCons a) (showCons b))
  (=.<=) (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) (C_FrontendParams y1 y2 y3 y4 y5 y6 y7) d cs =
    (&) ((=:<=) x1 y1 d cs) ((&) ((=:<=) x2 y2 d cs) ((&) ((=:<=) x3 y3 d cs)
    ((&) ((=:<=) x4 y4 d cs) ((&) ((=:<=) x5 y5 d cs) ((&) ((=:<=) x6 y6 d cs)
    ((=:<=) x7 y7 d cs) d cs) d cs) d cs) d cs) d cs) d cs
  (=.<=) a b cd _ = Fail_C_Success cd (unificationFail (showCons a) (showCons
    b))
  bind cd i (C_FrontendParams x3 x4 x5 x6 x7 x8 x9) = (i :=: ChooseN 0 7) :
    concat [bind cd (leftID (leftID (leftID i))) x3, bind cd (rightID (leftID
    (leftID i))) x4, bind cd (leftID (rightID (leftID i))) x5, bind cd (rightID
    (rightID (leftID i))) x6, bind cd (leftID (leftID (rightID i))) x7, bind cd
    (rightID (leftID (rightID i))) x8, bind cd (rightID (rightID i)) x9]
  bind d i (Choice_C_FrontendParams cd j x y) = [ConstraintChoice cd j (bind d i
    x) (bind d i y)]
  bind d i (Choices_C_FrontendParams cd j@(FreeID _ _) xs) = bindOrNarrow d i cd
    j xs
  bind d i (Choices_C_FrontendParams cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (bind d i) xs)]
  bind _ _ (Choices_C_FrontendParams cd i _) = error
    ("Distribution.FrontendParams.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_FrontendParams cd info) = [Unsolvable info]
  bind d i (Guard_C_FrontendParams cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i (C_FrontendParams x3 x4 x5 x6 x7 x8 x9) = (i :=: ChooseN 0 7) :
    [leftID (leftID (leftID i)) :=: LazyBind (lazyBind cd (leftID (leftID
    (leftID i))) x3), rightID (leftID (leftID i)) :=: LazyBind (lazyBind cd
    (rightID (leftID (leftID i))) x4), leftID (rightID (leftID i)) :=: LazyBind
    (lazyBind cd (leftID (rightID (leftID i))) x5), rightID (rightID (leftID
    i)) :=: LazyBind (lazyBind cd (rightID (rightID (leftID i))) x6), leftID
    (leftID (rightID i)) :=: LazyBind (lazyBind cd (leftID (leftID (rightID i)))
    x7), rightID (leftID (rightID i)) :=: LazyBind (lazyBind cd (rightID (leftID
    (rightID i))) x8), rightID (rightID i) :=: LazyBind (lazyBind cd (rightID
    (rightID i)) x9)]
  lazyBind d i (Choice_C_FrontendParams cd j x y) = [ConstraintChoice cd j
    (lazyBind d i x) (lazyBind d i y)]
  lazyBind d i (Choices_C_FrontendParams cd j@(FreeID _ _) xs) =
    lazyBindOrNarrow d i cd j xs
  lazyBind d i (Choices_C_FrontendParams cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_FrontendParams cd i _) = error
    ("Distribution.FrontendParams.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_FrontendParams cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_FrontendParams cd c e) = getConstrList c ++ [i :=:
    LazyBind (lazyBind d i e)]

instance Curry_Prelude.Curry C_FrontendParams where
  (=?=) (Choice_C_FrontendParams cd i x y) z d cs = narrow cd i
    ((Curry_Prelude.=?=) x z d cs) ((Curry_Prelude.=?=) y z d cs)
  (=?=) (Choices_C_FrontendParams cd i xs) y d cs = narrows cs cd i (\x ->
    (Curry_Prelude.=?=) x y d cs) xs
  (=?=) (Guard_C_FrontendParams cd c e) y d cs = guardCons cd c
    ((Curry_Prelude.=?=) e y d (addCs c cs))
  (=?=) (Fail_C_FrontendParams cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_FrontendParams cd i x y) d cs = narrow cd i
    ((Curry_Prelude.=?=) z x d cs) ((Curry_Prelude.=?=) z y d cs)
  (=?=) y (Choices_C_FrontendParams cd i xs) d cs = narrows cs cd i (\x ->
    (Curry_Prelude.=?=) y x d cs) xs
  (=?=) y (Guard_C_FrontendParams cd c e) d cs = guardCons cd c
    ((Curry_Prelude.=?=) y e d (addCs c cs))
  (=?=) _ (Fail_C_FrontendParams cd info) _ _ = failCons cd info
  (=?=) (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) (C_FrontendParams y1 y2 y3 y4 y5 y6 y7) d cs =
    Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x2 y2 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x3 y3 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x4 y4 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x5 y5 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x6 y6 d cs)
    ((Curry_Prelude.=?=) x7 y7 d cs) d cs) d cs) d cs) d cs) d cs) d cs
  (<?=) (Choice_C_FrontendParams cd i x y) z d cs = narrow cd i
    ((Curry_Prelude.<?=) x z d cs) ((Curry_Prelude.<?=) y z d cs)
  (<?=) (Choices_C_FrontendParams cd i xs) y d cs = narrows cs cd i (\x ->
    (Curry_Prelude.<?=) x y d cs) xs
  (<?=) (Guard_C_FrontendParams cd c e) y d cs = guardCons cd c
    ((Curry_Prelude.<?=) e y d (addCs c cs))
  (<?=) (Fail_C_FrontendParams cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_FrontendParams cd i x y) d cs = narrow cd i
    ((Curry_Prelude.<?=) z x d cs) ((Curry_Prelude.<?=) z y d cs)
  (<?=) y (Choices_C_FrontendParams cd i xs) d cs = narrows cs cd i (\x ->
    (Curry_Prelude.<?=) y x d cs) xs
  (<?=) y (Guard_C_FrontendParams cd c e) d cs = guardCons cd c
    ((Curry_Prelude.<?=) y e d (addCs c cs))
  (<?=) _ (Fail_C_FrontendParams cd info) _ _ = failCons cd info
  (<?=) (C_FrontendParams x1 x2 x3 x4 x5 x6 x7) (C_FrontendParams y1 y2 y3 y4 y5 y6 y7) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x1 y1 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x2 y2 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x2 y2 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x3 y3 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x3 y3 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x4 y4 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x4 y4 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x5 y5 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x5 y5 d cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x6 y6 d cs)
    (Curry_Prelude.d_OP_amp_amp ((Curry_Prelude.=?=) x6 y6 d cs)
    ((Curry_Prelude.<?=) x7 y7 d cs) d cs) d cs) d cs) d cs) d cs) d cs) d cs) d
    cs) d cs) d cs) d cs) d cs

d_C_rcFileName :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_rcFileName cd cs = let x1 = Curry_Prelude.OP_Cons (Curry_Prelude.C_Char
                             '.'#) (Curry_Prelude.d_OP_plus_plus
                             (d_C_curryCompiler cd cs)
                             (Curry_Prelude.toCurryString "rc") cd cs)
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_System.d_C_getEnviron
  (Curry_Prelude.toCurryString "HOME") cd cs) (Curry_Prelude.d_OP_dot
  Curry_Prelude.d_C_return (Curry_Prelude.d_C_flip
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) x1) cd cs) cd cs

d_C_rcFileContents :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_C_rcFileContents cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_rcFileName cd cs)
  Curry_PropertyFile.d_C_readPropertyFile cd cs

d_C_getRcVar :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_getRcVar x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_getRcVars
  (Curry_Prelude.OP_Cons x1 Curry_Prelude.OP_List) cd cs)
  (Curry_Prelude.d_OP_dot Curry_Prelude.d_C_return Curry_Prelude.d_C_head cd cs)
  cd cs

d_C_getRcVars :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)))
d_C_getRcVars x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_rcFileContents cd cs)
  (d_OP_getRcVars_dot_uscore_hash_lambda1 x1) cd cs

d_OP_getRcVars_dot_uscore_hash_lambda1 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_OP_getRcVars_dot_uscore_hash_lambda1 x1 x2 cd cs = Curry_Prelude.d_C_return
  (Curry_Prelude.d_C_map (Curry_Prelude.d_C_flip (acceptCs id
  Curry_Prelude.d_C_lookup) (Curry_Prelude.d_C_map
  d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 x2 cd cs))
  (Curry_Prelude.d_C_map (Curry_Prelude.d_C_map Curry_Char.d_C_toLower) x1 cd
  cs) cd cs) cd cs

d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.OP_Tuple2
    (Curry_Prelude.d_C_map Curry_Char.d_C_toLower x2 cd cs) x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 l cd cs)
    (d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_getRcVars_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.getRcVars._#lambda1._#lambda2" [show x1] info)
  _ -> failCons cd (consFail "Distribution.getRcVars._#lambda1._#lambda2"
    (showCons x1))

d_C_splitModuleFileName :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_splitModuleFileName x1 x2 cd cs = let x3 = Curry_Prelude.d_C_apply
                                            (d_C_splitModuleIdentifiers cd cs)
                                            x1 cd cs
  in d_C__case_37 x2 x3 cd cs

d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base l cd cs)
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.splitModuleFileName._#selFP5#base" [show x1] info)
  _ -> failCons cd (consFail "Distribution.splitModuleFileName._#selFP5#base"
    (showCons x1))

d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext l cd cs)
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.splitModuleFileName._#selFP6#ext" [show x1] info)
  _ -> failCons cd (consFail "Distribution.splitModuleFileName._#selFP6#ext"
    (showCons x1))

d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre l cd cs)
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.splitModuleFileName._#selFP3#pre" [show x1] info)
  _ -> failCons cd (consFail "Distribution.splitModuleFileName._#selFP3#pre"
    (showCons x1))

d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf l cd cs)
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.splitModuleFileName._#selFP4#suf" [show x1] info)
  _ -> failCons cd (consFail "Distribution.splitModuleFileName._#selFP4#suf"
    (showCons x1))

d_C_splitModuleIdentifiers :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_splitModuleIdentifiers cd cs = Curry_List.d_C_split (Curry_Prelude.d_C_flip
  (acceptCs id Curry_Prelude.d_OP_eq_eq) (Curry_Prelude.C_Char '.'#))

d_C_joinModuleIdentifiers :: Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_joinModuleIdentifiers cd cs = Curry_Prelude.d_C_foldr1 (acceptCs id
  d_OP_joinModuleIdentifiers_dot_combine_dot_27)

d_OP_joinModuleIdentifiers_dot_combine_dot_27 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_joinModuleIdentifiers_dot_combine_dot_27 x1 x2 cd cs =
  Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char
  '.'#) x2) cd cs

d_C_stripCurrySuffix :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_stripCurrySuffix x1 cd cs = d_C__case_33 x1 (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_elem (Curry_Prelude.d_C_apply
  (Curry_FileGoodies.d_C_fileSuffix cd cs) x1 cd cs) cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "curry")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "lcurry")
  Curry_Prelude.OP_List)) cd cs) cd cs

d_C_modNameToPath :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_modNameToPath cd cs = Curry_Prelude.d_OP_dot (Curry_Prelude.d_C_foldr1
  (Curry_FilePath.d_OP_lt_slash_gt cd cs)) (Curry_List.d_C_split
  (Curry_Prelude.d_C_flip (acceptCs id Curry_Prelude.d_OP_eq_eq)
  (Curry_Prelude.C_Char '.'#))) cd cs

d_C_currySubdir :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_currySubdir cd cs = Curry_Prelude.toCurryString ".curry"

d_C_inCurrySubdir :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_inCurrySubdir x1 cd cs = let x2 = Curry_FilePath.d_C_splitFileName x1 cd cs
                                 x3 = d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base
                                   x2 cd cs
                                 x4 = d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file
                                   x2 cd cs
  in Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) x3 cd cs) (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs)
  (d_C_currySubdir cd cs) cd cs) (Curry_Prelude.d_C_apply (d_C_modNameToPath cd
  cs) x4 cd cs) cd cs) cd cs

d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base l cd cs)
    (d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_inCurrySubdir_dot_uscore_hash_selFP8_hash_base e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.inCurrySubdir._#selFP8#base" [show x1] info)
  _ -> failCons cd (consFail "Distribution.inCurrySubdir._#selFP8#base"
    (showCons x1))

d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file l cd cs)
    (d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_inCurrySubdir_dot_uscore_hash_selFP9_hash_file e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.inCurrySubdir._#selFP9#file" [show x1] info)
  _ -> failCons cd (consFail "Distribution.inCurrySubdir._#selFP9#file"
    (showCons x1))

d_C_inCurrySubdirModule :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_inCurrySubdirModule x1 x2 cd cs = let x3 = d_C_splitModuleFileName x1 x2 cd
                                            cs
                                          x4 = d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP
                                            x3 cd cs
                                          x5 = d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP
                                            x3 cd cs
  in Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) x4 cd cs) (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs)
  (d_C_currySubdir cd cs) cd cs) x5 cd cs) cd cs

d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP l cd cs)
    (d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_inCurrySubdirModule_dot_uscore_hash_selFP11_hash_dirP e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.inCurrySubdirModule._#selFP11#dirP" [show x1] info)
  _ -> failCons cd (consFail "Distribution.inCurrySubdirModule._#selFP11#dirP"
    (showCons x1))

d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP l cd cs)
    (d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_inCurrySubdirModule_dot_uscore_hash_selFP12_hash_modP e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "Distribution.inCurrySubdirModule._#selFP12#modP" [show x1] info)
  _ -> failCons cd (consFail "Distribution.inCurrySubdirModule._#selFP12#modP"
    (showCons x1))

d_C_addCurrySubdir :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_addCurrySubdir x1 cd cs = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) x1 cd cs) (d_C_currySubdir cd cs) cd
  cs

d_C_getSysLibPath :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_getSysLibPath cd cs = d_C__case_32 (d_C_curryCompiler cd cs) cd cs

d_C_lookupFileInLoadPath :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_lookupFileInLoadPath x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_getLoadPathForFile x1 cd cs) (Curry_FileGoodies.d_C_lookupFileInPath
  (Curry_Prelude.d_C_apply (Curry_FilePath.d_C_takeFileName cd cs) x1 cd cs)
  (Curry_Prelude.OP_Cons Curry_Prelude.OP_List Curry_Prelude.OP_List)) cd cs

d_C_findFileInLoadPath :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C_findFileInLoadPath x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_getLoadPathForFile x1 cd cs) (Curry_FileGoodies.d_C_getFileInPath
  (Curry_Prelude.d_C_apply (Curry_FilePath.d_C_takeFileName cd cs) x1 cd cs)
  (Curry_Prelude.OP_Cons Curry_Prelude.OP_List Curry_Prelude.OP_List)) cd cs

d_C_readFirstFileInLoadPath :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C_readFirstFileInLoadPath x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_findFileInLoadPath x1 cd cs) Curry_Prelude.d_C_readFile cd cs

d_C_getLoadPath :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_getLoadPath cd cs = d_C_getLoadPathForFile (Curry_Prelude.toCurryString
  "xxx") cd cs

d_C_getLoadPathForFile :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_getLoadPathForFile x1 cd cs = let x2 = Curry_Prelude.d_C_concatMap
                                        d_OP_getLoadPathForFile_dot_uscore_hash_lambda5
                                        cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (d_C_getSysLibPath cd cs)
  (d_OP_getLoadPathForFile_dot_uscore_hash_lambda6 x2 x1) cd cs

d_OP_getLoadPathForFile_dot_uscore_hash_lambda5 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_getLoadPathForFile_dot_uscore_hash_lambda5 x1 cd cs = Curry_Prelude.OP_Cons
  x1 (Curry_Prelude.OP_Cons (d_C_addCurrySubdir x1 cd cs) Curry_Prelude.OP_List)

d_OP_getLoadPathForFile_dot_uscore_hash_lambda6 :: (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_OP_getLoadPathForFile_dot_uscore_hash_lambda6 x1 x2 x3 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (d_C_getRcVar (Curry_Prelude.toCurryString
  "libraries") cd cs)
  (d_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7 x1 x2
  x3) cd cs

nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6 :: Func (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6 x1 x2 x3 s cd cs = let s0 = s
  in s0 `seq` Curry_Prelude.nd_OP_gt_gt_eq (d_C_getRcVar
  (Curry_Prelude.toCurryString "libraries") cd cs) (wrapNX id
  (nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7 x1
  x2 x3)) s0 cd cs

d_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7 :: (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7 x1 x2 x3 x4 cd cs =
  let x5 = Curry_Prelude.d_C_apply (Curry_FilePath.d_C_dropFileName cd cs) x2 cd
        cs
  in d_C__case_11 x3 x4 x5 x1 (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
  (d_C_curryCompiler cd cs) cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "pakcs") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "kics") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "kics2") Curry_Prelude.OP_List))) cd cs) cd cs

nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7 :: Func
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7 x1 x2 x3 x4 s cd cs =
  let s4 = s
  in s4 `seq` (let s0 = leftSupply s4
                   s3 = rightSupply s4
  in s0 `seq` (s3 `seq` (let x5 = Curry_Prelude.nd_C_apply (wrapDX id
                               (Curry_FilePath.d_C_dropFileName cd cs)) x2 s0 cd
                               cs
  in let s2 = leftSupply s3
         s1 = rightSupply s3
  in s2 `seq` (s1 `seq` nd_C__case_11 x3 x4 x5 x1 (Curry_Prelude.nd_C_apply
  (wrapDX id (Curry_Prelude.d_C_elem (d_C_curryCompiler cd cs) cd cs))
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "pakcs")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "kics")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "kics2")
  Curry_Prelude.OP_List))) s1 cd cs) s2 cd cs))))

d_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 :: (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 x1 x2 x3 x4 x5 cd cs =
  let x6 = Curry_Prelude.d_C_maybe Curry_Prelude.OP_List
        (Curry_FilePath.d_C_splitSearchPath cd cs) x3 cd cs
      x7 = Curry_Prelude.OP_Cons x2 (Curry_Prelude.OP_Cons
        (Curry_FilePath.d_C_normalise (Curry_Prelude.d_C_apply
        (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs)
        (d_C_currySubdir cd cs) cd cs) x2 cd cs) cd cs) Curry_Prelude.OP_List)
  in Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_return
  (Curry_Prelude.d_OP_plus_plus x7 (Curry_Prelude.d_C_apply x1
  (Curry_Prelude.OP_Cons x2 (Curry_Prelude.d_OP_plus_plus (d_C__case_10 x5
  (Curry_Prelude.d_C_null x5 cd cs) cd cs) (Curry_Prelude.d_OP_plus_plus x6 x4
  cd cs) cd cs)) cd cs) cd cs) cd cs

nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 :: Func
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8 x1 x2 x3 x4 x5 s cd cs =
  let s7 = s
  in s7 `seq` (let s0 = leftSupply s7
                   s8 = rightSupply s7
                   s3 = leftSupply s8
                   s6 = rightSupply s8
  in s0 `seq` (s8 `seq` (s3 `seq` (s6 `seq` (let x6 = Curry_Prelude.nd_C_maybe
                                                   Curry_Prelude.OP_List (wrapDX
                                                   id
                                                   (Curry_FilePath.d_C_splitSearchPath
                                                   cd cs)) x3 s0 cd cs
                                                 x7 = Curry_Prelude.OP_Cons x2
                                                   (Curry_Prelude.OP_Cons
                                                   (Curry_FilePath.d_C_normalise
                                                   (let s2 = leftSupply s3
                                                        s1 = rightSupply s3
                                                   in s2 `seq` (s1 `seq`
                                                   Curry_Prelude.nd_C_apply
                                                   (Curry_Prelude.nd_C_apply
                                                   (wrapDX (wrapDX id)
                                                   (Curry_FilePath.d_OP_lt_slash_gt
                                                   cd cs)) (d_C_currySubdir cd
                                                   cs) s1 cd cs) x2 s2 cd cs))
                                                   cd cs) Curry_Prelude.OP_List)
  in let s5 = leftSupply s6
         s4 = rightSupply s6
  in s5 `seq` (s4 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id
  Curry_Prelude.d_C_return) (Curry_Prelude.d_OP_plus_plus x7
  (Curry_Prelude.nd_C_apply x1 (Curry_Prelude.OP_Cons x2
  (Curry_Prelude.d_OP_plus_plus (d_C__case_10 x5 (Curry_Prelude.d_C_null x5 cd
  cs) cd cs) (Curry_Prelude.d_OP_plus_plus x6 x4 cd cs) cd cs)) s4 cd cs) cd cs)
  s5 cd cs))))))

d_C_getLoadPathForModule :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_getLoadPathForModule x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_getSysLibPath cd cs) (d_OP_getLoadPathForModule_dot_uscore_hash_lambda9
  x1) cd cs

d_OP_getLoadPathForModule_dot_uscore_hash_lambda9 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_getLoadPathForModule_dot_uscore_hash_lambda9 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (d_C_getRcVar (Curry_Prelude.toCurryString
  "libraries") cd cs)
  (d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10 x1
  x2) cd cs

d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10 x1 x2 x3 cd cs =
  let x4 = Curry_Prelude.d_C_apply (Curry_FilePath.d_C_dropFileName cd cs) x1 cd
        cs
  in d_C__case_9 x2 x3 x4 (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
  (d_C_curryCompiler cd cs) cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "pakcs") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "kics") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "kics2") Curry_Prelude.OP_List))) cd cs) cd cs

d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10_dot_uscore_hash_lambda11 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10_dot_uscore_hash_lambda11 x1 x2 x3 x4 cd cs =
  let x5 = Curry_Prelude.d_C_maybe Curry_Prelude.OP_List
        d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10_dot_uscore_hash_lambda11_dot_uscore_hash_lambda12
        x2 cd cs
  in Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_return (Curry_Prelude.OP_Cons
  x1 (Curry_Prelude.d_OP_plus_plus (d_C__case_8 x4 (Curry_Prelude.d_C_null x4 cd
  cs) cd cs) (Curry_Prelude.d_OP_plus_plus x5 x3 cd cs) cd cs)) cd cs

d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10_dot_uscore_hash_lambda11_dot_uscore_hash_lambda12 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10_dot_uscore_hash_lambda11_dot_uscore_hash_lambda12 x1 cd cs =
  d_C__case_7 x1 (Curry_Prelude.d_C_null x1 cd cs) cd cs

d_C_lookupModuleSourceInLoadPath :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_C_lookupModuleSourceInLoadPath x1 cd cs = let x2 = Curry_Prelude.d_C_apply
                                                  (Curry_FilePath.d_C_takeFileName
                                                  cd cs) x1 cd cs
                                                x3 = Curry_Prelude.d_OP_plus_plus
                                                  (Curry_Prelude.d_C_apply
                                                  (d_C_modNameToPath cd cs) x2
                                                  cd cs)
                                                  (Curry_Prelude.toCurryString
                                                  ".lcurry") cd cs
                                                x4 = Curry_Prelude.d_OP_plus_plus
                                                  (Curry_Prelude.d_C_apply
                                                  (d_C_modNameToPath cd cs) x2
                                                  cd cs)
                                                  (Curry_Prelude.toCurryString
                                                  ".curry") cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (d_C_getLoadPathForModule x1 cd cs)
  (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 x4 x3) cd cs

d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 x1 x2 x3 cd cs =
  case x3 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_return Curry_Prelude.C_Nothing cd
    cs
  Curry_Prelude.OP_Cons x4 x5 -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_Directory.d_C_doesFileExist (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs) x4 cd cs)
    x2 cd cs) cd cs)
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13
    x4 x5 x1 x2) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 x1 x2 l cd
    cs) (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 x1 x2 r
    cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 x1 x2 z cd
    cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution.lookupModuleSourceInLoadPath.lookupSourceInPath.88" [show x1
    , show x2, show x3] info)
  _ -> failCons cd (consFail
    "Distribution.lookupModuleSourceInLoadPath.lookupSourceInPath.88" (showCons
    x3))

d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13 x1 x2 x3 x4 x5 cd cs =
  case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (Curry_Prelude.OP_Tuple2 x1 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs) x1 cd cs)
    x4 cd cs))) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_Directory.d_C_doesFileExist (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs) x1 cd cs)
    x3 cd cs) cd cs)
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14
    x1 x2 x3 x4) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13
    x1 x2 x3 x4 l cd cs)
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13
    x1 x2 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13
    x1 x2 x3 x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13
    x1 x2 x3 x4 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution.lookupModuleSourceInLoadPath.lookupSourceInPath.88._#lambda13"
    [show x1, show x2, show x3, show x4, show x5] info)
  _ -> failCons cd (consFail
    "Distribution.lookupModuleSourceInLoadPath.lookupSourceInPath.88._#lambda13"
    (showCons x5))

d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14 x1 x2 x3 x4 x5 cd cs =
  case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (Curry_Prelude.OP_Tuple2 x1 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs) x1 cd cs)
    x3 cd cs))) cd cs
  Curry_Prelude.C_False -> d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88
    x3 x4 x2 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14
    x1 x2 x3 x4 l cd cs)
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14
    x1 x2 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14
    x1 x2 x3 x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_lookupModuleSourceInLoadPath_dot_lookupSourceInPath_dot_88_dot_uscore_hash_lambda13_dot_uscore_hash_lambda14
    x1 x2 x3 x4 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution.lookupModuleSourceInLoadPath.lookupSourceInPath.88._#lambda13._#lambda14"
    [show x1, show x2, show x3, show x4, show x5] info)
  _ -> failCons cd (consFail
    "Distribution.lookupModuleSourceInLoadPath.lookupSourceInPath.88._#lambda13._#lambda14"
    (showCons x5))

d_C_defaultParams :: Cover -> ConstStore -> C_FrontendParams
d_C_defaultParams cd cs = C_FrontendParams Curry_Prelude.C_False
  Curry_Prelude.C_True Curry_Prelude.C_True Curry_Prelude.C_Nothing
  Curry_Prelude.C_Nothing Curry_Prelude.C_Nothing Curry_Prelude.OP_List

d_C_rcParams :: Cover -> ConstStore -> Curry_Prelude.C_IO C_FrontendParams
d_C_rcParams cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_getRcVars
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "curryextensions")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "warnoverlapping")
  Curry_Prelude.OP_List)) cd cs) d_OP_rcParams_dot_uscore_hash_lambda15 cd cs

d_OP_rcParams_dot_uscore_hash_lambda15 :: Curry_Prelude.OP_List
  (Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO C_FrontendParams
d_OP_rcParams_dot_uscore_hash_lambda15 x1 cd cs = case x1 of
  Curry_Prelude.OP_Cons x2 x3 -> d_C__case_6 x2 x3 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_rcParams_dot_uscore_hash_lambda15 l cd cs)
    (d_OP_rcParams_dot_uscore_hash_lambda15 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_rcParams_dot_uscore_hash_lambda15 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_rcParams_dot_uscore_hash_lambda15 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution.rcParams._#lambda15" [show x1] info)
  _ -> failCons cd (consFail "Distribution.rcParams._#lambda15" (showCons x1))

d_C_setQuiet :: Curry_Prelude.C_Bool -> C_FrontendParams -> Cover -> ConstStore
  -> C_FrontendParams
d_C_setQuiet x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x1 x4 x5 x6 x7 x8 x9
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setQuiet x1 l cd cs)
    (d_C_setQuiet x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setQuiet x1 z cd
    cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setQuiet x1 e cd $! addCs c
    cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.setQuiet"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setQuiet" (showCons x2))

d_C_setExtended :: Curry_Prelude.C_Bool -> C_FrontendParams -> Cover
  -> ConstStore -> C_FrontendParams
d_C_setExtended x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x3 x1 x5 x6 x7 x8 x9
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setExtended x1 l cd cs)
    (d_C_setExtended x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setExtended x1 z
    cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setExtended x1 e cd $!
    addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.setExtended" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setExtended" (showCons x2))

d_C_setOverlapWarn :: Curry_Prelude.C_Bool -> C_FrontendParams -> Cover
  -> ConstStore -> C_FrontendParams
d_C_setOverlapWarn x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x3 x4 x1 x6 x7 x8 x9
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setOverlapWarn x1 l cd cs)
    (d_C_setOverlapWarn x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setOverlapWarn x1
    z cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setOverlapWarn x1 e cd $!
    addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.setOverlapWarn" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setOverlapWarn" (showCons x2))

d_C_setFullPath :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> C_FrontendParams -> Cover -> ConstStore
  -> C_FrontendParams
d_C_setFullPath x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x3 x4 x5
    (Curry_Prelude.C_Just x1) x7 x8 x9
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setFullPath x1 l cd cs)
    (d_C_setFullPath x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setFullPath x1 z
    cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setFullPath x1 e cd $!
    addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.setFullPath" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setFullPath" (showCons x2))

d_C_setHtmlDir :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> C_FrontendParams
  -> Cover -> ConstStore -> C_FrontendParams
d_C_setHtmlDir x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x3 x4 x5 x6
    (Curry_Prelude.C_Just x1) x8 x9
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setHtmlDir x1 l cd cs)
    (d_C_setHtmlDir x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setHtmlDir x1 z
    cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setHtmlDir x1 e cd $! addCs
    c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.setHtmlDir" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setHtmlDir" (showCons x2))

d_C_setLogfile :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> C_FrontendParams
  -> Cover -> ConstStore -> C_FrontendParams
d_C_setLogfile x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x3 x4 x5 x6 x7
    (Curry_Prelude.C_Just x1) x9
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setLogfile x1 l cd cs)
    (d_C_setLogfile x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setLogfile x1 z
    cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setLogfile x1 e cd $! addCs
    c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.setLogfile" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setLogfile" (showCons x2))

d_C_setSpecials :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> C_FrontendParams -> Cover -> ConstStore -> C_FrontendParams
d_C_setSpecials x1 x2 cd cs = case x2 of
  C_FrontendParams x3 x4 x5 x6 x7 x8 x9 -> C_FrontendParams x3 x4 x5 x6 x7 x8 x1
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_setSpecials x1 l cd cs)
    (d_C_setSpecials x1 r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_setSpecials x1 z
    cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_setSpecials x1 e cd $!
    addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.setSpecials" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution.setSpecials" (showCons x2))

d_C_quiet :: C_FrontendParams -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_quiet x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x2
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_quiet l cd cs) (d_C_quiet r
    cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_quiet z cd cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_quiet e cd $! addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.quiet"
    [show x1] info)
  _ -> failCons cd (consFail "Distribution.quiet" (showCons x1))

d_C_extended :: C_FrontendParams -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_extended x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x3
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_extended l cd cs)
    (d_C_extended r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_extended z cd cs)
    xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_extended e cd $! addCs c
    cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.extended"
    [show x1] info)
  _ -> failCons cd (consFail "Distribution.extended" (showCons x1))

d_C_overlapWarn :: C_FrontendParams -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_overlapWarn x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x4
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_overlapWarn l cd cs)
    (d_C_overlapWarn r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_overlapWarn z cd
    cs) xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_overlapWarn e cd $! addCs c
    cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail
    "Distribution.overlapWarn" [show x1] info)
  _ -> failCons cd (consFail "Distribution.overlapWarn" (showCons x1))

d_C_fullPath :: C_FrontendParams -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_fullPath x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x5
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_fullPath l cd cs)
    (d_C_fullPath r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_fullPath z cd cs)
    xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_fullPath e cd $! addCs c
    cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.fullPath"
    [show x1] info)
  _ -> failCons cd (consFail "Distribution.fullPath" (showCons x1))

d_C_htmldir :: C_FrontendParams -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_htmldir x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x6
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_htmldir l cd cs)
    (d_C_htmldir r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_htmldir z cd cs)
    xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_htmldir e cd $! addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.htmldir"
    [show x1] info)
  _ -> failCons cd (consFail "Distribution.htmldir" (showCons x1))

d_C_logfile :: C_FrontendParams -> Cover -> ConstStore -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_logfile x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x7
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_logfile l cd cs)
    (d_C_logfile r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_logfile z cd cs)
    xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_logfile e cd $! addCs c cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.logfile"
    [show x1] info)
  _ -> failCons cd (consFail "Distribution.logfile" (showCons x1))

d_C_specials :: C_FrontendParams -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_specials x1 cd cs = case x1 of
  C_FrontendParams x2 x3 x4 x5 x6 x7 x8 -> x8
  Choice_C_FrontendParams d i l r -> narrow d i (d_C_specials l cd cs)
    (d_C_specials r cd cs)
  Choices_C_FrontendParams d i xs -> narrows cs d i (\z -> d_C_specials z cd cs)
    xs
  Guard_C_FrontendParams d c e -> guardCons d c (d_C_specials e cd $! addCs c
    cs)
  Fail_C_FrontendParams d info -> failCons d (traceFail "Distribution.specials"
    [show x1] info)
  _ -> failCons cd (consFail "Distribution.specials" (showCons x1))

d_C_callFrontend :: C_FrontendTarget -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_callFrontend x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_rcParams cd cs)
  (d_OP_callFrontend_dot_uscore_hash_lambda16 x2 x1) cd cs

d_OP_callFrontend_dot_uscore_hash_lambda16 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> C_FrontendTarget -> C_FrontendParams -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_callFrontend_dot_uscore_hash_lambda16 x1 x2 x3 cd cs =
  d_C_callFrontendWithParams x2 x3 x1 cd cs

d_C_callFrontendWithParams :: C_FrontendTarget -> C_FrontendParams
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_callFrontendWithParams x1 x2 x3 cd cs = let x4 = Curry_Prelude.d_OP_gt_gt_eq
                                                  (Curry_Prelude.d_C_maybe
                                                  (d_C_getLoadPathForModule x3
                                                  cd cs)
                                                  Curry_Prelude.d_C_return
                                                  (d_C_fullPath x2 cd cs) cd cs)
                                                  d_OP_callFrontendWithParams_dot_uscore_hash_lambda17
                                                  cd cs
                                                x5 = Curry_Prelude.toCurryString
                                                  "--no-verb --no-warn --no-overlap-warn"
                                                x6 = Curry_Prelude.d_C_unwords
                                                  (Curry_Prelude.OP_Cons
                                                  (d_C__case_4 x2 x5 (d_C_quiet
                                                  x2 cd cs) cd cs)
                                                  (Curry_Prelude.OP_Cons
                                                  (d_C__case_3 x2 (d_C_extended
                                                  x2 cd cs) cd cs)
                                                  (Curry_Prelude.OP_Cons
                                                  (d_C__case_2 x2
                                                  (d_C_overlapWarn x2 cd cs) cd
                                                  cs) (Curry_Prelude.OP_Cons
                                                  (Curry_Prelude.d_C_maybe
                                                  Curry_Prelude.OP_List
                                                  (Curry_Prelude.d_OP_plus_plus
                                                  (Curry_Prelude.toCurryString
                                                  "--htmldir=")) (d_C_htmldir x2
                                                  cd cs) cd cs)
                                                  (Curry_Prelude.OP_Cons
                                                  (d_C_specials x2 cd cs)
                                                  Curry_Prelude.OP_List))))) cd
                                                  cs
  in Curry_Prelude.d_OP_gt_gt_eq x4
  (d_OP_callFrontendWithParams_dot_uscore_hash_lambda18 x3 x2 x6 x1) cd cs

d_OP_callFrontendWithParams_dot_quote_dot_184 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_callFrontendWithParams_dot_quote_dot_184 x1 cd cs = Curry_Prelude.OP_Cons
  (Curry_Prelude.C_Char '"'#) (Curry_Prelude.d_OP_plus_plus x1
  (Curry_Prelude.toCurryString "\"") cd cs)

d_OP_callFrontendWithParams_dot_uscore_hash_lambda17 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_callFrontendWithParams_dot_uscore_hash_lambda17 x1 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.d_OP_plus_plus
  (d_OP_callFrontendWithParams_dot_quote_dot_184 (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs)
  (d_C_installDir cd cs) cd cs) (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_slash_gt cd cs)
  (Curry_Prelude.toCurryString "bin") cd cs) (Curry_Prelude.toCurryString
  "cymake") cd cs) cd cs) cd cs) (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_concatMap (Curry_Prelude.d_OP_dot
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString " -i"))
  d_OP_callFrontendWithParams_dot_quote_dot_184 cd cs) cd cs) x1 cd cs) cd cs)
  cd cs

d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 :: C_FrontendTarget
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 x1 cd cs = case x1 of
  C_FCY -> Curry_Prelude.toCurryString "--flat"
  C_FINT -> Curry_Prelude.toCurryString "--flat"
  C_ACY -> Curry_Prelude.toCurryString "--acy"
  C_UACY -> Curry_Prelude.toCurryString "--uacy"
  C_HTML -> Curry_Prelude.toCurryString "--html"
  C_CY -> Curry_Prelude.toCurryString "--parse-only"
  Choice_C_FrontendTarget d i l r -> narrow d i
    (d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 l cd cs)
    (d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 r cd cs)
  Choices_C_FrontendTarget d i xs -> narrows cs d i (\z ->
    d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 z cd cs) xs
  Guard_C_FrontendTarget d c e -> guardCons d c
    (d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 e cd $! addCs c
    cs)
  Fail_C_FrontendTarget d info -> failCons d (traceFail
    "Distribution.callFrontendWithParams.showFrontendTarget.184" [show x1] info)
  _ -> failCons cd (consFail
    "Distribution.callFrontendWithParams.showFrontendTarget.184" (showCons x1))

d_OP_callFrontendWithParams_dot_uscore_hash_lambda18 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> C_FrontendParams -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> C_FrontendTarget -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_OP_callFrontendWithParams_dot_uscore_hash_lambda18 x1 x2 x3 x4 x5 cd cs =
  let x6 = Curry_Prelude.d_C_maybe Curry_Prelude.OP_List Curry_Prelude.d_C_id
        (d_C_logfile x2 cd cs) cd cs
      x7 = Curry_Prelude.d_OP_plus_plus x5 (Curry_Prelude.d_OP_plus_plus
        (Curry_Prelude.toCurryString " ") (Curry_Prelude.d_OP_plus_plus
        (d_OP_callFrontendWithParams_dot_showFrontendTarget_dot_184 x4 cd cs)
        (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString " ")
        (Curry_Prelude.d_OP_plus_plus x3 (Curry_Prelude.d_OP_plus_plus
        (Curry_Prelude.toCurryString " ") (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_C_takeFileName cd cs) x1 cd cs) cd cs) cd cs) cd cs)
        cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (d_C__case_1 x6 x7 (Curry_Prelude.d_C_null x6
  cd cs) cd cs)
  d_OP_callFrontendWithParams_dot_uscore_hash_lambda18_dot_uscore_hash_lambda19
  cd cs

d_OP_callFrontendWithParams_dot_uscore_hash_lambda18_dot_uscore_hash_lambda19 :: Curry_Prelude.C_Int
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_callFrontendWithParams_dot_uscore_hash_lambda18_dot_uscore_hash_lambda19 x1 cd cs =
  d_C__case_0 x1 (Curry_Prelude.d_OP_eq_eq x1 (Curry_Prelude.C_Int 0#) cd cs) cd
  cs

d_C__case_0 :: Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_0 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_done cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_ioError
    (Curry_Prelude.d_C_userError (Curry_Prelude.toCurryString
    "Illegal source program") cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_0 x1 l cd cs)
    (d_C__case_0 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_0 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_0 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_0" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution._case_0" (showCons x2))

d_C__case_1 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Int
d_C__case_1 x6 x7 x8 cd cs = case x8 of
  Curry_Prelude.C_True -> Curry_System.d_C_system x7 cd cs
  Curry_Prelude.C_False -> Curry_System.d_C_system (Curry_Prelude.d_OP_plus_plus
    x7 (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString " > ")
    (Curry_Prelude.d_OP_plus_plus x6 (Curry_Prelude.toCurryString " 2>&1") cd
    cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 x6 x7 l cd cs)
    (d_C__case_1 x6 x7 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 x6 x7
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_1 x6 x7 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_1" [show x6, show x7, show x8] info)
  _ -> failCons cd (consFail "Distribution._case_1" (showCons x8))

d_C__case_2 :: C_FrontendParams -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_2 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.toCurryString "--no-overlap-warn"
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x2 l cd cs)
    (d_C__case_2 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_2 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_2" [show x2, show x3] info)
  _ -> failCons cd (consFail "Distribution._case_2" (showCons x3))

d_C__case_3 :: C_FrontendParams -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_3 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "--extended"
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x2 l cd cs)
    (d_C__case_3 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_3 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_3" [show x2, show x3] info)
  _ -> failCons cd (consFail "Distribution._case_3" (showCons x3))

d_C__case_4 :: C_FrontendParams -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_4 x2 x5 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> x5
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_4 x2 x5 l cd cs)
    (d_C__case_4 x2 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_4 x2 x5
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_4 x2 x5 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_4" [show x2, show x5, show x6] info)
  _ -> failCons cd (consFail "Distribution._case_4" (showCons x6))

d_C__case_6 :: Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_FrontendParams
d_C__case_6 x2 x3 cd cs = case x3 of
  Curry_Prelude.OP_Cons x4 x5 -> d_C__case_5 x4 x2 x5 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_6 x2 l cd cs)
    (d_C__case_6 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_6 x2 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_6 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_6" [show x2, show x3] info)
  _ -> failCons cd (consFail "Distribution._case_6" (showCons x3))

d_C__case_5 :: Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List (Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_FrontendParams
d_C__case_5 x4 x2 x5 cd cs = case x5 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_return
    (Curry_Prelude.d_OP_dollar (d_C_setExtended (Curry_Prelude.d_OP_slash_eq x2
    (Curry_Prelude.C_Just (Curry_Prelude.toCurryString "no")) cd cs))
    (Curry_Prelude.d_OP_dollar (d_C_setOverlapWarn (Curry_Prelude.d_OP_slash_eq
    x4 (Curry_Prelude.C_Just (Curry_Prelude.toCurryString "no")) cd cs))
    (d_C_defaultParams cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_5 x4 x2 l cd cs)
    (d_C__case_5 x4 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_5 x4
    x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_5 x4 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_5" [show x4, show x2, show x5] info)
  _ -> failCons cd (consFail "Distribution._case_5" (showCons x5))

d_C__case_7 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_7 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_C_apply
    (Curry_FilePath.d_C_splitSearchPath cd cs) x1 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_7 x1 l cd cs)
    (d_C__case_7 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_7 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_7 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_7" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution._case_7" (showCons x2))

d_C__case_8 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_8 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_C_apply
    (Curry_FilePath.d_C_splitSearchPath cd cs) x4 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_8 x4 l cd cs)
    (d_C__case_8 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_8 x4 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_8 x4 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_8" [show x4, show x5] info)
  _ -> failCons cd (consFail "Distribution._case_8" (showCons x5))

d_C__case_9 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_9 x2 x3 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_System.d_C_getEnviron (Curry_Prelude.toCurryString "CURRYPATH") cd
    cs)
    (d_OP_getLoadPathForModule_dot_uscore_hash_lambda9_dot_uscore_hash_lambda10_dot_uscore_hash_lambda11
    x4 x3 x2) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getLoadPathForModule: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_9 x2 x3 x4 l cd
    cs) (d_C__case_9 x2 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_9 x2 x3
    x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_9 x2 x3 x4 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_9" [show x2, show x3, show x4, show x5] info)
  _ -> failCons cd (consFail "Distribution._case_9" (showCons x5))

d_C__case_10 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_10 x5 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_C_apply
    (Curry_FilePath.d_C_splitSearchPath cd cs) x5 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_10 x5 l cd cs)
    (d_C__case_10 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_10 x5 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_10 x5 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_10" [show x5, show x6] info)
  _ -> failCons cd (consFail "Distribution._case_10" (showCons x6))

d_C__case_11 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  -> Cover -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_11 x3 x4 x5 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_System.d_C_getEnviron (Curry_Prelude.toCurryString "CURRYPATH") cd
    cs)
    (d_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8
    x1 x5 x4 x3) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getLoadPathForFile: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_11 x3 x4 x5 x1 l
    cd cs) (d_C__case_11 x3 x4 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_11 x3
    x4 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_11 x3 x4 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_11" [show x3, show x4, show x5, show x1, show x6] info)
  _ -> failCons cd (consFail "Distribution._case_11" (showCons x6))

nd_C__case_11 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Func
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
nd_C__case_11 x3 x4 x5 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt_eq (Curry_System.d_C_getEnviron
    (Curry_Prelude.toCurryString "CURRYPATH") cd cs) (wrapNX id
    (nd_OP_getLoadPathForFile_dot_uscore_hash_lambda6_dot_uscore_hash_lambda7_dot_uscore_hash_lambda8
    x1 x5 x4 x3)) s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getLoadPathForFile: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_11 x3 x4 x5 x1 l
    s cd cs) (nd_C__case_11 x3 x4 x5 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_11 x3
    x4 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_11 x3 x4 x5 x1 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_11" [show x3, show x4, show x5, show x1, show x6] info)
  _ -> failCons cd (consFail "Distribution._case_11" (showCons x6))

d_C__case_32 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_32 x3 cd cs = case x3 of
  Curry_Prelude.OP_Cons x1 x2 -> d_C__case_31 x1 x2 (Curry_Prelude.d_OP_eq_eq x1
    (Curry_Prelude.C_Char 'p'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_32 l cd cs)
    (d_C__case_32 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_32 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_32 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_32" [show x3] info)
  _ -> failCons cd (consFail "Distribution._case_32" (showCons x3))

d_C__case_31 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_31 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C__case_30 x2 cd cs
  Curry_Prelude.C_False -> d_C__case_21 x1 x2 (Curry_Prelude.d_OP_eq_eq x1
    (Curry_Prelude.C_Char 'k'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_31 x1 x2 l cd cs)
    (d_C__case_31 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_31 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_31 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_31" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "Distribution._case_31" (showCons x3))

d_C__case_21 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_21 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C__case_20 x2 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_21 x1 x2 l cd cs)
    (d_C__case_21 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_21 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_21 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_21" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "Distribution._case_21" (showCons x3))

d_C__case_20 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_20 x2 cd cs = case x2 of
  Curry_Prelude.OP_Cons x13 x14 -> d_C__case_19 x13 x14
    (Curry_Prelude.d_OP_eq_eq x13 (Curry_Prelude.C_Char 'i'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_20 l cd cs)
    (d_C__case_20 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_20 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_20 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_20" [show x2] info)
  _ -> failCons cd (consFail "Distribution._case_20" (showCons x2))

d_C__case_19 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_19 x13 x14 x15 cd cs = case x15 of
  Curry_Prelude.C_True -> d_C__case_18 x14 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_19 x13 x14 l cd
    cs) (d_C__case_19 x13 x14 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_19 x13
    x14 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_19 x13 x14 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_19" [show x13, show x14, show x15] info)
  _ -> failCons cd (consFail "Distribution._case_19" (showCons x15))

d_C__case_18 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_18 x14 cd cs = case x14 of
  Curry_Prelude.OP_Cons x15 x16 -> d_C__case_17 x15 x16
    (Curry_Prelude.d_OP_eq_eq x15 (Curry_Prelude.C_Char 'c'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_18 l cd cs)
    (d_C__case_18 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_18 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_18 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_18" [show x14] info)
  _ -> failCons cd (consFail "Distribution._case_18" (showCons x14))

d_C__case_17 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_17 x15 x16 x17 cd cs = case x17 of
  Curry_Prelude.C_True -> d_C__case_16 x16 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_17 x15 x16 l cd
    cs) (d_C__case_17 x15 x16 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_17 x15
    x16 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_17 x15 x16 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_17" [show x15, show x16, show x17] info)
  _ -> failCons cd (consFail "Distribution._case_17" (showCons x17))

d_C__case_16 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_16 x16 cd cs = case x16 of
  Curry_Prelude.OP_Cons x17 x18 -> d_C__case_15 x17 x18
    (Curry_Prelude.d_OP_eq_eq x17 (Curry_Prelude.C_Char 's'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_16 l cd cs)
    (d_C__case_16 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_16 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_16 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_16" [show x16] info)
  _ -> failCons cd (consFail "Distribution._case_16" (showCons x16))

d_C__case_15 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_15 x17 x18 x19 cd cs = case x19 of
  Curry_Prelude.C_True -> d_C__case_14 x18 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_15 x17 x18 l cd
    cs) (d_C__case_15 x17 x18 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_15 x17
    x18 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_15 x17 x18 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_15" [show x17, show x18, show x19] info)
  _ -> failCons cd (consFail "Distribution._case_15" (showCons x19))

d_C__case_14 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_14 x18 cd cs = case x18 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_return (Curry_Prelude.OP_Cons
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (d_C_installDir cd cs) cd cs)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString "src")
    cd cs) (Curry_Prelude.toCurryString "lib") cd cs) cd cs)
    Curry_Prelude.OP_List) cd cs
  Curry_Prelude.OP_Cons x19 x20 -> d_C__case_13 x19 x20
    (Curry_Prelude.d_OP_eq_eq x19 (Curry_Prelude.C_Char '2'#) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_14 l cd cs)
    (d_C__case_14 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_14 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_14 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_14" [show x18] info)
  _ -> failCons cd (consFail "Distribution._case_14" (showCons x18))

d_C__case_13 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_13 x19 x20 x21 cd cs = case x21 of
  Curry_Prelude.C_True -> d_C__case_12 x20 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_13 x19 x20 l cd
    cs) (d_C__case_13 x19 x20 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_13 x19
    x20 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_13 x19 x20 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_13" [show x19, show x20, show x21] info)
  _ -> failCons cd (consFail "Distribution._case_13" (showCons x21))

d_C__case_12 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_12 x20 cd cs = case x20 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_return (Curry_Prelude.OP_Cons
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (d_C_installDir cd cs) cd cs)
    (Curry_Prelude.toCurryString "lib") cd cs) (Curry_Prelude.OP_Cons
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (d_C_installDir cd cs) cd cs)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString "lib")
    cd cs) (Curry_Prelude.toCurryString "meta") cd cs) cd cs)
    Curry_Prelude.OP_List)) cd cs
  Curry_Prelude.OP_Cons x21 x22 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_12 l cd cs)
    (d_C__case_12 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_12 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_12 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_12" [show x20] info)
  _ -> failCons cd (consFail "Distribution._case_12" (showCons x20))

d_C__case_30 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_30 x2 cd cs = case x2 of
  Curry_Prelude.OP_Cons x3 x4 -> d_C__case_29 x3 x4 (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.C_Char 'a'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_30 l cd cs)
    (d_C__case_30 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_30 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_30 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_30" [show x2] info)
  _ -> failCons cd (consFail "Distribution._case_30" (showCons x2))

d_C__case_29 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_29 x3 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> d_C__case_28 x4 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_29 x3 x4 l cd cs)
    (d_C__case_29 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_29 x3
    x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_29 x3 x4 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_29" [show x3, show x4, show x5] info)
  _ -> failCons cd (consFail "Distribution._case_29" (showCons x5))

d_C__case_28 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_28 x4 cd cs = case x4 of
  Curry_Prelude.OP_Cons x5 x6 -> d_C__case_27 x5 x6 (Curry_Prelude.d_OP_eq_eq x5
    (Curry_Prelude.C_Char 'k'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_28 l cd cs)
    (d_C__case_28 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_28 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_28 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_28" [show x4] info)
  _ -> failCons cd (consFail "Distribution._case_28" (showCons x4))

d_C__case_27 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_27 x5 x6 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C__case_26 x6 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_27 x5 x6 l cd cs)
    (d_C__case_27 x5 x6 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_27 x5
    x6 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_27 x5 x6 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_27" [show x5, show x6, show x7] info)
  _ -> failCons cd (consFail "Distribution._case_27" (showCons x7))

d_C__case_26 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_26 x6 cd cs = case x6 of
  Curry_Prelude.OP_Cons x7 x8 -> d_C__case_25 x7 x8 (Curry_Prelude.d_OP_eq_eq x7
    (Curry_Prelude.C_Char 'c'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_26 l cd cs)
    (d_C__case_26 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_26 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_26 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_26" [show x6] info)
  _ -> failCons cd (consFail "Distribution._case_26" (showCons x6))

d_C__case_25 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_25 x7 x8 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> d_C__case_24 x8 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_25 x7 x8 l cd cs)
    (d_C__case_25 x7 x8 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_25 x7
    x8 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_25 x7 x8 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_25" [show x7, show x8, show x9] info)
  _ -> failCons cd (consFail "Distribution._case_25" (showCons x9))

d_C__case_24 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_24 x8 cd cs = case x8 of
  Curry_Prelude.OP_Cons x9 x10 -> d_C__case_23 x9 x10 (Curry_Prelude.d_OP_eq_eq
    x9 (Curry_Prelude.C_Char 's'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_24 l cd cs)
    (d_C__case_24 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_24 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_24 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_24" [show x8] info)
  _ -> failCons cd (consFail "Distribution._case_24" (showCons x8))

d_C__case_23 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_23 x9 x10 x11 cd cs = case x11 of
  Curry_Prelude.C_True -> d_C__case_22 x10 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_23 x9 x10 l cd
    cs) (d_C__case_23 x9 x10 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_23 x9
    x10 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_23 x9 x10 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_23" [show x9, show x10, show x11] info)
  _ -> failCons cd (consFail "Distribution._case_23" (showCons x11))

d_C__case_22 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_22 x10 cd cs = case x10 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_return (Curry_Prelude.OP_Cons
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (d_C_installDir cd cs) cd cs)
    (Curry_Prelude.toCurryString "lib") cd cs) (Curry_Prelude.OP_Cons
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (d_C_installDir cd cs) cd cs)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString "lib")
    cd cs) (Curry_Prelude.toCurryString "meta") cd cs) cd cs)
    Curry_Prelude.OP_List)) cd cs
  Curry_Prelude.OP_Cons x11 x12 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString
    "Distribution.getSysLibPath: unknown curryCompiler") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_22 l cd cs)
    (d_C__case_22 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_22 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_22 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_22" [show x10] info)
  _ -> failCons cd (consFail "Distribution._case_22" (showCons x10))

d_C__case_33 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_33 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_apply
    (Curry_FileGoodies.d_C_stripSuffix cd cs) x1 cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_33 x1 l cd cs)
    (d_C__case_33 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_33 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_33 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_33" [show x1, show x2] info)
  _ -> failCons cd (consFail "Distribution._case_33" (showCons x2))

d_C__case_37 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_37 x2 x3 cd cs = case x3 of
  Curry_Prelude.OP_Cons x4 x5 -> d_C__case_36 x3 x2 x5 cd cs
  Curry_Prelude.OP_List -> let x16 = Curry_FilePath.d_C_splitExtension x2 cd cs
                               x17 = d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base
                                 x16 cd cs
                               x18 = d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext
                                 x16 cd cs
                               x19 = Curry_FilePath.d_C_splitDirectories x17 cd
                                 cs
                               x20 = Curry_Prelude.d_C_splitAt
                                 (Curry_Prelude.d_OP_minus
                                 (Curry_Prelude.d_C_length x19 cd cs)
                                 (Curry_Prelude.d_C_length x3 cd cs) cd cs) x19
                                 cd cs
                               x21 = d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre
                                 x20 cd cs
                               x22 = d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf
                                 x20 cd cs
                               x23 = d_C__case_34 x21 (Curry_Prelude.d_C_null
                                 x21 cd cs) cd cs
    in Curry_Prelude.OP_Tuple2 x23 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_dot_gt cd cs)
    (Curry_FilePath.d_C_joinPath x22 cd cs) cd cs) x18 cd cs)
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_37 x2 l cd cs)
    (d_C__case_37 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_37 x2
    z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_37 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_37" [show x2, show x3] info)
  _ -> failCons cd (consFail "Distribution._case_37" (showCons x3))

d_C__case_34 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_34 x21 x22 cd cs = case x22 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_FilePath.d_C_addTrailingPathSeparator
    (Curry_FilePath.d_C_joinPath x21 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_34 x21 l cd cs)
    (d_C__case_34 x21 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_34 x21
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_34 x21 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_34" [show x21, show x22] info)
  _ -> failCons cd (consFail "Distribution._case_34" (showCons x22))

d_C__case_36 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_36 x3 x2 x5 cd cs = case x5 of
  Curry_Prelude.OP_List -> Curry_FilePath.d_C_splitFileName x2 cd cs
  Curry_Prelude.OP_Cons x6 x7 -> let x8 = Curry_FilePath.d_C_splitExtension x2
                                       cd cs
                                     x9 = d_OP_splitModuleFileName_dot_uscore_hash_selFP5_hash_base
                                       x8 cd cs
                                     x10 = d_OP_splitModuleFileName_dot_uscore_hash_selFP6_hash_ext
                                       x8 cd cs
                                     x11 = Curry_FilePath.d_C_splitDirectories
                                       x9 cd cs
                                     x12 = Curry_Prelude.d_C_splitAt
                                       (Curry_Prelude.d_OP_minus
                                       (Curry_Prelude.d_C_length x11 cd cs)
                                       (Curry_Prelude.d_C_length x3 cd cs) cd
                                       cs) x11 cd cs
                                     x13 = d_OP_splitModuleFileName_dot_uscore_hash_selFP3_hash_pre
                                       x12 cd cs
                                     x14 = d_OP_splitModuleFileName_dot_uscore_hash_selFP4_hash_suf
                                       x12 cd cs
                                     x15 = d_C__case_35 x13
                                       (Curry_Prelude.d_C_null x13 cd cs) cd cs
    in Curry_Prelude.OP_Tuple2 x15 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_apply (Curry_FilePath.d_OP_lt_dot_gt cd cs)
    (Curry_FilePath.d_C_joinPath x14 cd cs) cd cs) x10 cd cs)
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_36 x3 x2 l cd
    cs) (d_C__case_36 x3 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_36 x3
    x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_36 x3 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "Distribution._case_36" [show x3, show x2, show x5] info)
  _ -> failCons cd (consFail "Distribution._case_36" (showCons x5))

d_C__case_35 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_35 x13 x14 cd cs = case x14 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_FilePath.d_C_addTrailingPathSeparator
    (Curry_FilePath.d_C_joinPath x13 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_35 x13 l cd cs)
    (d_C__case_35 x13 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_35 x13
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_35 x13 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "Distribution._case_35" [show x13, show x14] info)
  _ -> failCons cd (consFail "Distribution._case_35" (showCons x14))

d_C_curryCompiler :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_curryCompiler cd cs = external_d_C_curryCompiler cd cs

d_C_curryCompilerMajorVersion :: Cover -> ConstStore -> Curry_Prelude.C_Int
d_C_curryCompilerMajorVersion cd cs = external_d_C_curryCompilerMajorVersion cd
  cs

d_C_curryCompilerMinorVersion :: Cover -> ConstStore -> Curry_Prelude.C_Int
d_C_curryCompilerMinorVersion cd cs = external_d_C_curryCompilerMinorVersion cd
  cs

d_C_curryRuntime :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_curryRuntime cd cs = external_d_C_curryRuntime cd cs

d_C_curryRuntimeMajorVersion :: Cover -> ConstStore -> Curry_Prelude.C_Int
d_C_curryRuntimeMajorVersion cd cs = external_d_C_curryRuntimeMajorVersion cd cs

d_C_curryRuntimeMinorVersion :: Cover -> ConstStore -> Curry_Prelude.C_Int
d_C_curryRuntimeMinorVersion cd cs = external_d_C_curryRuntimeMinorVersion cd cs

d_C_installDir :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_installDir cd cs = external_d_C_installDir cd cs

external_d_C_curryCompiler :: Cover -> ConstStore -> Curry_Prelude.C_String
external_d_C_curryCompiler _ _ = toCurry "kics2"

external_d_C_curryCompilerMajorVersion ::  Cover -> ConstStore -> Curry_Prelude.C_Int
external_d_C_curryCompilerMajorVersion _ _ = toCurry I.majorVersion

external_d_C_curryCompilerMinorVersion ::  Cover -> ConstStore -> Curry_Prelude.C_Int
external_d_C_curryCompilerMinorVersion _ _ = toCurry I.minorVersion

external_d_C_curryRuntime ::  Cover -> ConstStore -> Curry_Prelude.C_String
external_d_C_curryRuntime _ _ = toCurry I.runtime

external_d_C_curryRuntimeMajorVersion ::  Cover -> ConstStore -> Curry_Prelude.C_Int
external_d_C_curryRuntimeMajorVersion _ _ = toCurry I.runtimeMajor

external_d_C_curryRuntimeMinorVersion ::  Cover -> ConstStore -> Curry_Prelude.C_Int
external_d_C_curryRuntimeMinorVersion _ _ = toCurry I.runtimeMinor

external_d_C_installDir ::  Cover -> ConstStore -> Curry_Prelude.C_String
external_d_C_installDir _ _ = toCurry I.installDir
