{-# LANGUAGE MagicHash #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Curry_AbstractCurryGoodies
  ( d_OP_tilde_gt, d_C_baseType, d_C_listType, d_C_tupleType, d_C_ioType
  , d_C_maybeType, d_C_stringType, d_C_intType, d_C_floatType, d_C_boolType
  , d_C_unitType, d_C_dateType, d_C_typeName, d_C_typeVis, d_C_typeCons
  , d_C_funcName, d_C_funcVis, d_C_consName, d_C_consVis, d_C_isBaseType
  , d_C_isPolyType, d_C_isFunctionalType, d_C_isIOType, d_C_isIOReturnType
  , d_C_argTypes, d_C_resultType, d_C_tvarsOfType, d_C_modsOfType, d_C_cfunc
  , d_C_cmtfunc, d_C_simpleRule, d_C_guardedRule, d_C_noGuard, d_C_applyF
  , d_C_applyE, d_C_constF, d_C_applyV, d_C_applyJust, d_C_applyMaybe
  , d_C_tupleExpr, d_C_cBranch, d_C_tuplePattern, d_C_pVars, d_C_pChar, d_C_pNil
  , d_C_listPattern, d_C_stringPattern, d_C_list2ac, d_C_cChar, d_C_string2ac
  , d_C_pre, d_C_isPrelude, d_C_toVar, d_C_cvar, d_C_cpvar, d_C_ctvar )
  where

import Basics
import qualified Curry_AbstractCurry
import qualified Curry_List
import qualified Curry_Prelude


d_OP_tilde_gt :: Curry_AbstractCurry.C_CTypeExpr
  -> Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_OP_tilde_gt x1 x2 cd cs = Curry_AbstractCurry.C_CFuncType x1 x2

d_C_baseType :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_baseType x1 cd cs = Curry_AbstractCurry.C_CTCons x1 Curry_Prelude.OP_List

d_C_listType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C_listType x1 cd cs = Curry_AbstractCurry.C_CTCons (d_C_pre
  (Curry_Prelude.toCurryString "[]") cd cs) (Curry_Prelude.OP_Cons x1
  Curry_Prelude.OP_List)

d_C_tupleType :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_tupleType x1 cd cs = let x2 = Curry_Prelude.d_C_length x1 cd cs
  in d_C__case_14 x2 x1 (Curry_Prelude.d_OP_eq_eq x2 (Curry_Prelude.C_Int 0#) cd
  cs) cd cs

d_C_ioType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C_ioType x1 cd cs = Curry_AbstractCurry.C_CTCons (d_C_pre
  (Curry_Prelude.toCurryString "IO") cd cs) (Curry_Prelude.OP_Cons x1
  Curry_Prelude.OP_List)

d_C_maybeType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C_maybeType x1 cd cs = Curry_AbstractCurry.C_CTCons (d_C_pre
  (Curry_Prelude.toCurryString "Maybe") cd cs) (Curry_Prelude.OP_Cons x1
  Curry_Prelude.OP_List)

d_C_stringType :: Cover -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_stringType cd cs = d_C_baseType (d_C_pre (Curry_Prelude.toCurryString
  "String") cd cs) cd cs

d_C_intType :: Cover -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_intType cd cs = d_C_baseType (d_C_pre (Curry_Prelude.toCurryString "Int") cd
  cs) cd cs

d_C_floatType :: Cover -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_floatType cd cs = d_C_baseType (d_C_pre (Curry_Prelude.toCurryString
  "Float") cd cs) cd cs

d_C_boolType :: Cover -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_boolType cd cs = d_C_baseType (d_C_pre (Curry_Prelude.toCurryString "Bool")
  cd cs) cd cs

d_C_unitType :: Cover -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_unitType cd cs = d_C_baseType (d_C_pre (Curry_Prelude.toCurryString "()") cd
  cs) cd cs

d_C_dateType :: Cover -> ConstStore -> Curry_AbstractCurry.C_CTypeExpr
d_C_dateType cd cs = d_C_baseType (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "Time") (Curry_Prelude.toCurryString
  "CalendarTime")) cd cs

d_C_typeName :: Curry_AbstractCurry.C_CTypeDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_typeName x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CType x2 x3 x4 x5 -> x2
  Curry_AbstractCurry.C_CTypeSyn x6 x7 x8 x9 -> x6
  Curry_AbstractCurry.C_CNewType x10 x11 x12 x13 -> x10
  Curry_AbstractCurry.Choice_C_CTypeDecl d i l r -> narrow d i (d_C_typeName l
    cd cs) (d_C_typeName r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeDecl d i xs -> narrows cs d i (\z ->
    d_C_typeName z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeDecl d c e -> guardCons d c (d_C_typeName e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.typeName" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.typeName" (showCons x1))

d_C_typeVis :: Curry_AbstractCurry.C_CTypeDecl -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CVisibility
d_C_typeVis x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CType x2 x3 x4 x5 -> x3
  Curry_AbstractCurry.C_CTypeSyn x6 x7 x8 x9 -> x7
  Curry_AbstractCurry.C_CNewType x10 x11 x12 x13 -> x11
  Curry_AbstractCurry.Choice_C_CTypeDecl d i l r -> narrow d i (d_C_typeVis l cd
    cs) (d_C_typeVis r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeDecl d i xs -> narrows cs d i (\z ->
    d_C_typeVis z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeDecl d c e -> guardCons d c (d_C_typeVis e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.typeVis" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.typeVis" (showCons x1))

d_C_typeCons :: Curry_AbstractCurry.C_CTypeDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CConsDecl
d_C_typeCons x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CType x2 x3 x4 x5 -> x5
  Curry_AbstractCurry.C_CTypeSyn x6 x7 x8 x9 -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CNewType x10 x11 x12 x13 -> Curry_Prelude.OP_Cons x13
    Curry_Prelude.OP_List
  Curry_AbstractCurry.Choice_C_CTypeDecl d i l r -> narrow d i (d_C_typeCons l
    cd cs) (d_C_typeCons r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeDecl d i xs -> narrows cs d i (\z ->
    d_C_typeCons z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeDecl d c e -> guardCons d c (d_C_typeCons e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.typeCons" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.typeCons" (showCons x1))

d_C_funcName :: Curry_AbstractCurry.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_funcName x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CFunc x2 x3 x4 x5 x6 -> x2
  Curry_AbstractCurry.C_CmtFunc x7 x8 x9 x10 x11 x12 -> x8
  Curry_AbstractCurry.Choice_C_CFuncDecl d i l r -> narrow d i (d_C_funcName l
    cd cs) (d_C_funcName r cd cs)
  Curry_AbstractCurry.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C_funcName z cd cs) xs
  Curry_AbstractCurry.Guard_C_CFuncDecl d c e -> guardCons d c (d_C_funcName e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.funcName" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.funcName" (showCons x1))

d_C_funcVis :: Curry_AbstractCurry.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CVisibility
d_C_funcVis x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CFunc x2 x3 x4 x5 x6 -> x4
  Curry_AbstractCurry.C_CmtFunc x7 x8 x9 x10 x11 x12 -> x10
  Curry_AbstractCurry.Choice_C_CFuncDecl d i l r -> narrow d i (d_C_funcVis l cd
    cs) (d_C_funcVis r cd cs)
  Curry_AbstractCurry.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C_funcVis z cd cs) xs
  Curry_AbstractCurry.Guard_C_CFuncDecl d c e -> guardCons d c (d_C_funcVis e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.funcVis" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.funcVis" (showCons x1))

d_C_consName :: Curry_AbstractCurry.C_CConsDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_consName x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CCons x2 x3 x4 -> x2
  Curry_AbstractCurry.C_CRecord x5 x6 x7 -> x5
  Curry_AbstractCurry.Choice_C_CConsDecl d i l r -> narrow d i (d_C_consName l
    cd cs) (d_C_consName r cd cs)
  Curry_AbstractCurry.Choices_C_CConsDecl d i xs -> narrows cs d i (\z ->
    d_C_consName z cd cs) xs
  Curry_AbstractCurry.Guard_C_CConsDecl d c e -> guardCons d c (d_C_consName e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CConsDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.consName" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.consName" (showCons x1))

d_C_consVis :: Curry_AbstractCurry.C_CConsDecl -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CVisibility
d_C_consVis x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CCons x2 x3 x4 -> x3
  Curry_AbstractCurry.C_CRecord x5 x6 x7 -> x6
  Curry_AbstractCurry.Choice_C_CConsDecl d i l r -> narrow d i (d_C_consVis l cd
    cs) (d_C_consVis r cd cs)
  Curry_AbstractCurry.Choices_C_CConsDecl d i xs -> narrows cs d i (\z ->
    d_C_consVis z cd cs) xs
  Curry_AbstractCurry.Guard_C_CConsDecl d c e -> guardCons d c (d_C_consVis e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CConsDecl d info -> failCons d (traceFail
    "AbstractCurryGoodies.consVis" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.consVis" (showCons x1))

d_C_isBaseType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isBaseType x1 cd cs = let x2 = Curry_Prelude.C_False
  in d_C__case_11 x2 x1 cd cs

d_C_isPolyType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isPolyType x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTVar x2 -> Curry_Prelude.C_True
  Curry_AbstractCurry.C_CFuncType x3 x4 -> Curry_Prelude.d_OP_bar_bar
    (d_C_isPolyType x3 cd cs) (d_C_isPolyType x4 cd cs) cd cs
  Curry_AbstractCurry.C_CTCons x5 x6 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_any d_C_isPolyType cd cs) x6 cd cs
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C_isPolyType l
    cd cs) (d_C_isPolyType r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_isPolyType z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C_isPolyType e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies.isPolyType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.isPolyType" (showCons x1))

d_C_isFunctionalType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isFunctionalType x1 cd cs = let x2 = Curry_Prelude.C_False
  in d_C__case_10 x2 x1 cd cs

d_C_isIOType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isIOType x1 cd cs = let x2 = Curry_Prelude.C_False
  in d_C__case_9 x2 x1 cd cs

d_C_isIOReturnType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_C_isIOReturnType x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTVar x2 -> Curry_Prelude.C_False
  Curry_AbstractCurry.C_CFuncType x3 x4 -> Curry_Prelude.C_False
  Curry_AbstractCurry.C_CTCons x5 x6 -> Curry_Prelude.d_OP_amp_amp
    (Curry_Prelude.d_OP_eq_eq x5 (d_C_pre (Curry_Prelude.toCurryString "IO") cd
    cs) cd cs) (Curry_Prelude.d_OP_amp_amp (Curry_Prelude.d_OP_slash_eq
    (Curry_Prelude.d_C_head x6 cd cs) (Curry_AbstractCurry.C_CTCons (d_C_pre
    (Curry_Prelude.toCurryString "()") cd cs) Curry_Prelude.OP_List) cd cs)
    (Curry_Prelude.d_C_not (d_C_isFunctionalType (Curry_Prelude.d_C_head x6 cd
    cs) cd cs) cd cs) cd cs) cd cs
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i
    (d_C_isIOReturnType l cd cs) (d_C_isIOReturnType r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_isIOReturnType z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c
    (d_C_isIOReturnType e cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies.isIOReturnType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.isIOReturnType" (showCons
    x1))

d_C_argTypes :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CTypeExpr
d_C_argTypes x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTVar x2 -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CTCons x3 x4 -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CFuncType x5 x6 -> Curry_Prelude.OP_Cons x5
    (d_C_argTypes x6 cd cs)
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C_argTypes l
    cd cs) (d_C_argTypes r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_argTypes z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C_argTypes e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies.argTypes" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.argTypes" (showCons x1))

d_C_resultType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C_resultType x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTVar x2 -> Curry_AbstractCurry.C_CTVar x2
  Curry_AbstractCurry.C_CTCons x3 x4 -> Curry_AbstractCurry.C_CTCons x3 x4
  Curry_AbstractCurry.C_CFuncType x5 x6 -> d_C_resultType x6 cd cs
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C_resultType l
    cd cs) (d_C_resultType r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_resultType z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C_resultType e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies.resultType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.resultType" (showCons x1))

d_C_tvarsOfType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_tvarsOfType x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTVar x2 -> Curry_Prelude.OP_Cons x2
    Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CFuncType x3 x4 -> Curry_Prelude.d_OP_plus_plus
    (d_C_tvarsOfType x3 cd cs) (d_C_tvarsOfType x4 cd cs) cd cs
  Curry_AbstractCurry.C_CTCons x5 x6 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap d_C_tvarsOfType cd cs) x6 cd cs
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C_tvarsOfType
    l cd cs) (d_C_tvarsOfType r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_tvarsOfType z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C_tvarsOfType
    e cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies.tvarsOfType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.tvarsOfType" (showCons x1))

d_C_modsOfType :: Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_modsOfType x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTVar x2 -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CFuncType x3 x4 -> Curry_List.d_C_union (d_C_modsOfType
    x3 cd cs) (d_C_modsOfType x4 cd cs) cd cs
  Curry_AbstractCurry.C_CTCons x5 x6 -> d_C__case_8 x6 x5 cd cs
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C_modsOfType l
    cd cs) (d_C_modsOfType r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C_modsOfType z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C_modsOfType e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies.modsOfType" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.modsOfType" (showCons x1))

d_C_cfunc :: Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CVisibility -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CRule -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CFuncDecl
d_C_cfunc cd cs = acceptCs (acceptCs (acceptCs (acceptCs (acceptCs id))))
  Curry_AbstractCurry.C_CFunc

d_C_cmtfunc :: Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CVisibility -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CRule -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CFuncDecl
d_C_cmtfunc cd cs = acceptCs (acceptCs (acceptCs (acceptCs (acceptCs (acceptCs
  id))))) Curry_AbstractCurry.C_CmtFunc

d_C_simpleRule :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CPattern
  -> Curry_AbstractCurry.C_CExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CRule
d_C_simpleRule x1 x2 cd cs = Curry_AbstractCurry.C_CRule x1
  (Curry_AbstractCurry.C_CSimpleRhs x2 Curry_Prelude.OP_List)

d_C_guardedRule :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CPattern
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_AbstractCurry.C_CExpr
  Curry_AbstractCurry.C_CExpr) -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CLocalDecl -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CRule
d_C_guardedRule x1 x2 x3 cd cs = d_C__case_7 x2 x3 x1
  (Curry_Prelude.d_OP_amp_amp (Curry_Prelude.d_OP_eq_eq
  (Curry_Prelude.d_C_length x2 cd cs) (Curry_Prelude.C_Int 1#) cd cs)
  (Curry_Prelude.d_OP_eq_eq (Curry_Prelude.d_C_fst (Curry_Prelude.d_C_head x2 cd
  cs) cd cs) (Curry_AbstractCurry.C_CSymbol (d_C_pre
  (Curry_Prelude.toCurryString "success") cd cs)) cd cs) cd cs) cd cs

d_C_noGuard :: Curry_AbstractCurry.C_CExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 Curry_AbstractCurry.C_CExpr
  Curry_AbstractCurry.C_CExpr
d_C_noGuard x1 cd cs = Curry_Prelude.OP_Tuple2 (Curry_AbstractCurry.C_CSymbol
  (d_C_pre (Curry_Prelude.toCurryString "success") cd cs)) x1

d_C_applyF :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_applyF x1 x2 cd cs = Curry_Prelude.d_C_foldl (acceptCs (acceptCs id)
  Curry_AbstractCurry.C_CApply) (Curry_AbstractCurry.C_CSymbol x1) x2 cd cs

d_C_applyE :: Curry_AbstractCurry.C_CExpr -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_applyE x1 x2 cd cs = Curry_Prelude.d_C_foldl (acceptCs (acceptCs id)
  Curry_AbstractCurry.C_CApply) x1 x2 cd cs

d_C_constF :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CExpr
d_C_constF x1 cd cs = d_C_applyF x1 Curry_Prelude.OP_List cd cs

d_C_applyV :: Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CExpr
  -> Cover -> ConstStore -> Curry_AbstractCurry.C_CExpr
d_C_applyV x1 x2 cd cs = Curry_Prelude.d_C_foldl (acceptCs (acceptCs id)
  Curry_AbstractCurry.C_CApply) (Curry_AbstractCurry.C_CVar x1) x2 cd cs

d_C_applyJust :: Curry_AbstractCurry.C_CExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_applyJust x1 cd cs = d_C_applyF (d_C_pre (Curry_Prelude.toCurryString
  "Just") cd cs) (Curry_Prelude.OP_Cons x1 Curry_Prelude.OP_List) cd cs

d_C_applyMaybe :: Curry_AbstractCurry.C_CExpr -> Curry_AbstractCurry.C_CExpr
  -> Curry_AbstractCurry.C_CExpr -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_applyMaybe x1 x2 x3 cd cs = d_C_applyF (d_C_pre (Curry_Prelude.toCurryString
  "maybe") cd cs) (Curry_Prelude.OP_Cons x1 (Curry_Prelude.OP_Cons x2
  (Curry_Prelude.OP_Cons x3 Curry_Prelude.OP_List))) cd cs

d_C_tupleExpr :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CExpr -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CExpr
d_C_tupleExpr x1 cd cs = let x2 = Curry_Prelude.d_C_length x1 cd cs
  in d_C__case_5 x2 x1 (Curry_Prelude.d_OP_eq_eq x2 (Curry_Prelude.C_Int 0#) cd
  cs) cd cs

d_C_cBranch :: Curry_AbstractCurry.C_CPattern -> Curry_AbstractCurry.C_CExpr
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  Curry_AbstractCurry.C_CPattern Curry_AbstractCurry.C_CRhs
d_C_cBranch x1 x2 cd cs = Curry_Prelude.OP_Tuple2 x1
  (Curry_AbstractCurry.C_CSimpleRhs x2 Curry_Prelude.OP_List)

d_C_tuplePattern :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CPattern
  -> Cover -> ConstStore -> Curry_AbstractCurry.C_CPattern
d_C_tuplePattern x1 cd cs = let x2 = Curry_Prelude.d_C_length x1 cd cs
  in d_C__case_2 x2 x1 (Curry_Prelude.d_OP_eq_eq x2 (Curry_Prelude.C_Int 0#) cd
  cs) cd cs

d_C_pVars :: Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CPattern
d_C_pVars x1 cd cs = Curry_Prelude.d_C_map d_OP_pVars_dot_uscore_hash_lambda4
  (Curry_Prelude.d_C_enumFromTo (Curry_Prelude.C_Int 0#)
  (Curry_Prelude.d_OP_minus x1 (Curry_Prelude.C_Int 1#) cd cs) cd cs) cd cs

d_OP_pVars_dot_uscore_hash_lambda4 :: Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CPattern
d_OP_pVars_dot_uscore_hash_lambda4 x1 cd cs = Curry_AbstractCurry.C_CPVar
  (Curry_Prelude.OP_Tuple2 x1 (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "x") (Curry_Prelude.d_C_show x1 cd cs) cd cs))

d_C_pChar :: Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CPattern
d_C_pChar x1 cd cs = Curry_AbstractCurry.C_CPLit (Curry_AbstractCurry.C_CCharc
  x1)

d_C_pNil :: Cover -> ConstStore -> Curry_AbstractCurry.C_CPattern
d_C_pNil cd cs = Curry_AbstractCurry.C_CPComb (d_C_pre
  (Curry_Prelude.toCurryString "[]") cd cs) Curry_Prelude.OP_List

d_C_listPattern :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CPattern -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CPattern
d_C_listPattern x1 cd cs = case x1 of
  Curry_Prelude.OP_List -> d_C_pNil cd cs
  Curry_Prelude.OP_Cons x2 x3 -> Curry_AbstractCurry.C_CPComb (d_C_pre
    (Curry_Prelude.toCurryString ":") cd cs) (Curry_Prelude.OP_Cons x2
    (Curry_Prelude.OP_Cons (d_C_listPattern x3 cd cs) Curry_Prelude.OP_List))
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_listPattern l cd cs)
    (d_C_listPattern r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_listPattern
    z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C_listPattern e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "AbstractCurryGoodies.listPattern" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.listPattern" (showCons x1))

d_C_stringPattern :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_AbstractCurry.C_CPattern
d_C_stringPattern cd cs = Curry_Prelude.d_OP_dot d_C_listPattern
  (Curry_Prelude.d_C_map (Curry_Prelude.d_OP_dot (acceptCs id
  Curry_AbstractCurry.C_CPLit) (acceptCs id Curry_AbstractCurry.C_CCharc) cd
  cs)) cd cs

d_C_list2ac :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CExpr -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CExpr
d_C_list2ac x1 cd cs = case x1 of
  Curry_Prelude.OP_List -> d_C_constF (d_C_pre (Curry_Prelude.toCurryString
    "[]") cd cs) cd cs
  Curry_Prelude.OP_Cons x2 x3 -> d_C_applyF (d_C_pre
    (Curry_Prelude.toCurryString ":") cd cs) (Curry_Prelude.OP_Cons x2
    (Curry_Prelude.OP_Cons (d_C_list2ac x3 cd cs) Curry_Prelude.OP_List)) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_list2ac l cd cs)
    (d_C_list2ac r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_list2ac z cd
    cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C_list2ac e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "AbstractCurryGoodies.list2ac" [show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies.list2ac" (showCons x1))

d_C_cChar :: Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_cChar x1 cd cs = Curry_AbstractCurry.C_CLit (Curry_AbstractCurry.C_CCharc
  x1)

d_C_string2ac :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_AbstractCurry.C_CExpr
d_C_string2ac x1 cd cs = Curry_AbstractCurry.C_CLit
  (Curry_AbstractCurry.C_CStringc x1)

d_C_pre :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_pre x1 cd cs = Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "Prelude") x1

d_C_isPrelude :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isPrelude x1 cd cs = Curry_Prelude.d_OP_eq_eq x1
  (Curry_Prelude.toCurryString "Prelude") cd cs

d_C_toVar :: Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_toVar x1 cd cs = Curry_AbstractCurry.C_CVar (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.C_Int 1#) (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "x") (Curry_Prelude.d_C_show x1 cd cs) cd cs))

d_C_cvar :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C_cvar x1 cd cs = Curry_AbstractCurry.C_CVar (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.C_Int 1#) x1)

d_C_cpvar :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CPattern
d_C_cpvar x1 cd cs = Curry_AbstractCurry.C_CPVar (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.C_Int 1#) x1)

d_C_ctvar :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C_ctvar x1 cd cs = Curry_AbstractCurry.C_CTVar (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.C_Int 1#) x1)

d_C__case_2 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CPattern -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CPattern
d_C__case_2 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_AbstractCurry.C_CPComb (d_C_pre
    (Curry_Prelude.toCurryString "()") cd cs) Curry_Prelude.OP_List
  Curry_Prelude.C_False -> d_C__case_1 x2 x1 (Curry_Prelude.d_OP_eq_eq x2
    (Curry_Prelude.C_Int 1#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x2 x1 l cd cs)
    (d_C__case_2 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x2 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_2 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_2" [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_2" (showCons x3))

d_C__case_1 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CPattern -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CPattern
d_C__case_1 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_head x1 cd cs
  Curry_Prelude.C_False -> d_C__case_0 x1 x2 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_1 x2 x1 l cd cs)
    (d_C__case_1 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_1 x2 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_1 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_1" [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_1" (showCons x3))

d_C__case_0 :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CPattern
  -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CPattern
d_C__case_0 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_AbstractCurry.C_CPComb (d_C_pre
    (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '('#)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_take
    (Curry_Prelude.d_OP_minus x2 (Curry_Prelude.C_Int 1#) cd cs)
    (Curry_Prelude.d_C_repeat (Curry_Prelude.C_Char ','#) cd cs) cd cs)
    (Curry_Prelude.toCurryString ")") cd cs)) cd cs) x1
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_0 x1 x2 l cd cs)
    (d_C__case_0 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_0 x1 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_0 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_0" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_0" (showCons x3))

d_C__case_5 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CExpr -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C__case_5 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_constF (d_C_pre (Curry_Prelude.toCurryString "()")
    cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_4 x2 x1 (Curry_Prelude.d_OP_eq_eq x2
    (Curry_Prelude.C_Int 1#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_5 x2 x1 l cd cs)
    (d_C__case_5 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_5 x2 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_5 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_5" [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_5" (showCons x3))

d_C__case_4 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CExpr -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C__case_4 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_head x1 cd cs
  Curry_Prelude.C_False -> d_C__case_3 x1 x2 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_4 x2 x1 l cd cs)
    (d_C__case_4 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_4 x2 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_4 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_4" [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_4" (showCons x3))

d_C__case_3 :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CExpr
  -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CExpr
d_C__case_3 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_applyF (d_C_pre (Curry_Prelude.OP_Cons
    (Curry_Prelude.C_Char '('#) (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_take (Curry_Prelude.d_OP_minus x2 (Curry_Prelude.C_Int
    1#) cd cs) (Curry_Prelude.d_C_repeat (Curry_Prelude.C_Char ','#) cd cs) cd
    cs) (Curry_Prelude.toCurryString ")") cd cs)) cd cs) x1 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x1 x2 l cd cs)
    (d_C__case_3 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x1 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_3 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_3" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_3" (showCons x3))

d_C__case_7 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  Curry_AbstractCurry.C_CExpr Curry_AbstractCurry.C_CExpr)
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CLocalDecl
  -> Curry_Prelude.OP_List Curry_AbstractCurry.C_CPattern
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_AbstractCurry.C_CRule
d_C__case_7 x2 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_AbstractCurry.C_CRule x1
    (Curry_AbstractCurry.C_CSimpleRhs (Curry_Prelude.d_C_snd
    (Curry_Prelude.d_C_head x2 cd cs) cd cs) x3)
  Curry_Prelude.C_False -> d_C__case_6 x3 x2 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_7 x2 x3 x1 l cd
    cs) (d_C__case_7 x2 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_7 x2 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_7 x2 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_7" [show x2, show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_7" (showCons x4))

d_C__case_6 :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CLocalDecl
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 Curry_AbstractCurry.C_CExpr
  Curry_AbstractCurry.C_CExpr) -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CPattern -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CRule
d_C__case_6 x3 x2 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_AbstractCurry.C_CRule x1
    (Curry_AbstractCurry.C_CGuardedRhs x2 x3)
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_6 x3 x2 x1 l cd
    cs) (d_C__case_6 x3 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_6 x3 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_6 x3 x2 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_6" [show x3, show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_6" (showCons x4))

d_C__case_8 :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CTypeExpr
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_8 x6 x5 cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x7 x8 -> Curry_Prelude.d_OP_dollar
    (Curry_Prelude.d_C_foldr (acceptCs id Curry_List.d_C_union)
    (Curry_Prelude.OP_Cons x7 Curry_Prelude.OP_List)) (Curry_Prelude.d_C_map
    d_C_modsOfType x6 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_8 x6 l cd cs)
    (d_C__case_8 x6 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_8 x6
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_8 x6 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_8" [show x6, show x5] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_8" (showCons x5))

d_C__case_9 :: Curry_Prelude.C_Bool -> Curry_AbstractCurry.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_9 x2 x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTCons x3 x4 -> Curry_Prelude.d_OP_eq_eq x3 (d_C_pre
    (Curry_Prelude.toCurryString "IO") cd cs) cd cs
  Curry_AbstractCurry.C_CTVar x5 -> x2
  Curry_AbstractCurry.C_CFuncType x6 x7 -> x2
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C__case_9 x2 l
    cd cs) (d_C__case_9 x2 r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C__case_9 x2 z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C__case_9 x2 e
    cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_9" [show x2, show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_9" (showCons x1))

d_C__case_10 :: Curry_Prelude.C_Bool -> Curry_AbstractCurry.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_10 x2 x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CFuncType x3 x4 -> Curry_Prelude.C_True
  Curry_AbstractCurry.C_CTVar x5 -> x2
  Curry_AbstractCurry.C_CTCons x6 x7 -> x2
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C__case_10 x2
    l cd cs) (d_C__case_10 x2 r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C__case_10 x2 z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C__case_10 x2
    e cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_10" [show x2, show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_10" (showCons x1))

d_C__case_11 :: Curry_Prelude.C_Bool -> Curry_AbstractCurry.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_11 x2 x1 cd cs = case x1 of
  Curry_AbstractCurry.C_CTCons x3 x4 -> Curry_Prelude.d_C_null x4 cd cs
  Curry_AbstractCurry.C_CTVar x5 -> x2
  Curry_AbstractCurry.C_CFuncType x6 x7 -> x2
  Curry_AbstractCurry.Choice_C_CTypeExpr d i l r -> narrow d i (d_C__case_11 x2
    l cd cs) (d_C__case_11 x2 r cd cs)
  Curry_AbstractCurry.Choices_C_CTypeExpr d i xs -> narrows cs d i (\z ->
    d_C__case_11 x2 z cd cs) xs
  Curry_AbstractCurry.Guard_C_CTypeExpr d c e -> guardCons d c (d_C__case_11 x2
    e cd $! addCs c cs)
  Curry_AbstractCurry.Fail_C_CTypeExpr d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_11" [show x2, show x1] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_11" (showCons x1))

d_C__case_14 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CTypeExpr -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C__case_14 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_baseType (d_C_pre (Curry_Prelude.toCurryString
    "()") cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_13 x2 x1 (Curry_Prelude.d_OP_eq_eq x2
    (Curry_Prelude.C_Int 1#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_14 x2 x1 l cd cs)
    (d_C__case_14 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_14 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_14 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_14" [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_14" (showCons x3))

d_C__case_13 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_AbstractCurry.C_CTypeExpr -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C__case_13 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_head x1 cd cs
  Curry_Prelude.C_False -> d_C__case_12 x1 x2 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_13 x2 x1 l cd cs)
    (d_C__case_13 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_13 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_13 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_13" [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_13" (showCons x3))

d_C__case_12 :: Curry_Prelude.OP_List Curry_AbstractCurry.C_CTypeExpr
  -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_AbstractCurry.C_CTypeExpr
d_C__case_12 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_AbstractCurry.C_CTCons (d_C_pre
    (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '('#)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_take
    (Curry_Prelude.d_OP_minus x2 (Curry_Prelude.C_Int 1#) cd cs)
    (Curry_Prelude.d_C_repeat (Curry_Prelude.C_Char ','#) cd cs) cd cs)
    (Curry_Prelude.toCurryString ")") cd cs)) cd cs) x1
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_12 x1 x2 l cd cs)
    (d_C__case_12 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_12 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_12 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "AbstractCurryGoodies._case_12" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "AbstractCurryGoodies._case_12" (showCons x3))

